diff --git a/Assets/VRKeys/Prefabs/VRKeys.prefab b/Assets/VRKeys/Prefabs/VRKeys.prefab
index f14c1a3..b9a85fd 100644
--- a/Assets/VRKeys/Prefabs/VRKeys.prefab
+++ b/Assets/VRKeys/Prefabs/VRKeys.prefab
@@ -11,61 +11,41 @@ Prefab:
m_ParentPrefab: {fileID: 0}
m_RootGameObject: {fileID: 1000010614386324}
m_IsPrefabParent: 1
---- !u!1 &1000010033919940
+--- !u!1 &1000010145710606
GameObject:
- m_ObjectHideFlags: 1
+ m_ObjectHideFlags: 0
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
serializedVersion: 4
m_Component:
- - 4: {fileID: 4000012689466318}
- - 33: {fileID: 33000011880972442}
- - 65: {fileID: 65000011503203434}
- - 23: {fileID: 23000011467883974}
- - 114: {fileID: 114000010924209110}
+ - 224: {fileID: 224000011442836622}
+ - 223: {fileID: 223000011891530624}
+ - 114: {fileID: 114000012222189772}
m_Layer: 0
- m_Name: Medium
+ m_Name: Canvas
m_TagString: Untagged
m_Icon: {fileID: 0}
m_NavMeshLayer: 0
m_StaticEditorFlags: 0
- m_IsActive: 1
---- !u!1 &1000010089480526
+ m_IsActive: 0
+--- !u!1 &1000010174852680
GameObject:
m_ObjectHideFlags: 1
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
serializedVersion: 4
m_Component:
- - 4: {fileID: 4000011636982694}
- - 33: {fileID: 33000011144877132}
- - 65: {fileID: 65000010893494936}
- - 23: {fileID: 23000010025218198}
- - 114: {fileID: 114000014094018522}
+ - 4: {fileID: 4000010068502200}
+ - 33: {fileID: 33000012690690984}
+ - 65: {fileID: 65000012333261654}
+ - 114: {fileID: 114000010912951870}
m_Layer: 0
- m_Name: Small
+ m_Name: HandCollider
m_TagString: Untagged
m_Icon: {fileID: 0}
m_NavMeshLayer: 0
m_StaticEditorFlags: 0
m_IsActive: 1
---- !u!1 &1000010145710606
-GameObject:
- m_ObjectHideFlags: 0
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- serializedVersion: 4
- m_Component:
- - 224: {fileID: 224000011442836622}
- - 223: {fileID: 223000011891530624}
- - 114: {fileID: 114000012222189772}
- m_Layer: 0
- m_Name: Canvas
- m_TagString: Untagged
- m_Icon: {fileID: 0}
- m_NavMeshLayer: 0
- m_StaticEditorFlags: 0
- m_IsActive: 0
--- !u!1 &1000010243209718
GameObject:
m_ObjectHideFlags: 1
@@ -102,25 +82,6 @@ GameObject:
m_NavMeshLayer: 0
m_StaticEditorFlags: 0
m_IsActive: 1
---- !u!1 &1000010412975446
-GameObject:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- serializedVersion: 4
- m_Component:
- - 224: {fileID: 224000010573683446}
- - 33: {fileID: 33000011401375976}
- - 23: {fileID: 23000010809721506}
- - 222: {fileID: 222000012199324066}
- - 114: {fileID: 114000011854418384}
- m_Layer: 0
- m_Name: Label
- m_TagString: Untagged
- m_Icon: {fileID: 0}
- m_NavMeshLayer: 0
- m_StaticEditorFlags: 0
- m_IsActive: 1
--- !u!1 &1000010441867314
GameObject:
m_ObjectHideFlags: 1
@@ -147,6 +108,7 @@ GameObject:
m_Component:
- 4: {fileID: 4000013025176432}
- 114: {fileID: 114000011813929276}
+ - 114: {fileID: 114000011638992124}
m_Layer: 0
m_Name: VRKeys
m_TagString: Untagged
@@ -425,25 +387,6 @@ GameObject:
m_NavMeshLayer: 0
m_StaticEditorFlags: 0
m_IsActive: 1
---- !u!1 &1000012063527344
-GameObject:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- serializedVersion: 4
- m_Component:
- - 224: {fileID: 224000013948607280}
- - 33: {fileID: 33000012290704998}
- - 23: {fileID: 23000012023175106}
- - 222: {fileID: 222000010435183204}
- - 114: {fileID: 114000012236845518}
- m_Layer: 0
- m_Name: Label
- m_TagString: Untagged
- m_Icon: {fileID: 0}
- m_NavMeshLayer: 0
- m_StaticEditorFlags: 0
- m_IsActive: 1
--- !u!1 &1000012078599230
GameObject:
m_ObjectHideFlags: 1
@@ -518,25 +461,6 @@ GameObject:
m_NavMeshLayer: 0
m_StaticEditorFlags: 0
m_IsActive: 1
---- !u!1 &1000012535845966
-GameObject:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- serializedVersion: 4
- m_Component:
- - 4: {fileID: 4000011234500342}
- - 33: {fileID: 33000010091403864}
- - 65: {fileID: 65000012762395060}
- - 23: {fileID: 23000010407663374}
- - 114: {fileID: 114000011431146602}
- m_Layer: 0
- m_Name: Large
- m_TagString: Untagged
- m_Icon: {fileID: 0}
- m_NavMeshLayer: 0
- m_StaticEditorFlags: 0
- m_IsActive: 1
--- !u!1 &1000012589486870
GameObject:
m_ObjectHideFlags: 1
@@ -556,25 +480,6 @@ GameObject:
m_NavMeshLayer: 0
m_StaticEditorFlags: 0
m_IsActive: 1
---- !u!1 &1000012703070624
-GameObject:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- serializedVersion: 4
- m_Component:
- - 224: {fileID: 224000010236752756}
- - 33: {fileID: 33000013801103796}
- - 23: {fileID: 23000010311683274}
- - 222: {fileID: 222000012420626692}
- - 114: {fileID: 114000011040958896}
- m_Layer: 0
- m_Name: Label
- m_TagString: Untagged
- m_Icon: {fileID: 0}
- m_NavMeshLayer: 0
- m_StaticEditorFlags: 0
- m_IsActive: 1
--- !u!1 &1000012747880360
GameObject:
m_ObjectHideFlags: 1
@@ -585,14 +490,13 @@ GameObject:
- 4: {fileID: 4000013148173780}
- 33: {fileID: 33000011359002896}
- 65: {fileID: 65000011825665588}
- - 23: {fileID: 23000010536738872}
m_Layer: 0
- m_Name: Keyboard
+ m_Name: KeyboardCollider
m_TagString: Untagged
m_Icon: {fileID: 0}
m_NavMeshLayer: 0
m_StaticEditorFlags: 0
- m_IsActive: 0
+ m_IsActive: 1
--- !u!1 &1000012940491476
GameObject:
m_ObjectHideFlags: 0
@@ -737,6 +641,24 @@ GameObject:
m_NavMeshLayer: 0
m_StaticEditorFlags: 0
m_IsActive: 1
+--- !u!1 &1000013340159164
+GameObject:
+ m_ObjectHideFlags: 1
+ m_PrefabParentObject: {fileID: 0}
+ m_PrefabInternal: {fileID: 100100000}
+ serializedVersion: 4
+ m_Component:
+ - 4: {fileID: 4000013256322456}
+ - 33: {fileID: 33000011132834486}
+ - 65: {fileID: 65000010632855888}
+ - 114: {fileID: 114000013318402454}
+ m_Layer: 0
+ m_Name: HandCollider
+ m_TagString: Untagged
+ m_Icon: {fileID: 0}
+ m_NavMeshLayer: 0
+ m_StaticEditorFlags: 0
+ m_IsActive: 1
--- !u!1 &1000013364588658
GameObject:
m_ObjectHideFlags: 1
@@ -818,13 +740,26 @@ Transform:
m_PrefabInternal: {fileID: 100100000}
m_GameObject: {fileID: 1000010921968412}
m_LocalRotation: {x: -0, y: -0, z: -0, w: 1}
- m_LocalPosition: {x: -0.355, y: 0.000000059604645, z: 0.46000007}
+ m_LocalPosition: {x: -0.035, y: 0.000000059604645, z: 0.46000007}
m_LocalScale: {x: 0.14999999, y: 0.01, z: 0.14999999}
m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
m_Children:
- {fileID: 224000013779997978}
m_Father: {fileID: 4000013859835632}
- m_RootOrder: 10
+ m_RootOrder: 7
+--- !u!4 &4000010068502200
+Transform:
+ m_ObjectHideFlags: 1
+ m_PrefabParentObject: {fileID: 0}
+ m_PrefabInternal: {fileID: 100100000}
+ m_GameObject: {fileID: 1000010174852680}
+ m_LocalRotation: {x: 0, y: 0, z: 0, w: 1}
+ m_LocalPosition: {x: 0, y: -0.05, z: 0}
+ m_LocalScale: {x: 0.05, y: 0.05, z: 0.05}
+ m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
+ m_Children: []
+ m_Father: {fileID: 4000012218914916}
+ m_RootOrder: 2
--- !u!4 &4000010133606078
Transform:
m_ObjectHideFlags: 1
@@ -838,7 +773,7 @@ Transform:
m_Children:
- {fileID: 224000013427320980}
m_Father: {fileID: 4000013859835632}
- m_RootOrder: 12
+ m_RootOrder: 9
--- !u!4 &4000010234157170
Transform:
m_ObjectHideFlags: 1
@@ -859,13 +794,13 @@ Transform:
m_PrefabInternal: {fileID: 100100000}
m_GameObject: {fileID: 1000011692986572}
m_LocalRotation: {x: -0, y: -0, z: -0, w: 1}
- m_LocalPosition: {x: 0.525, y: 0, z: 0.46000004}
+ m_LocalPosition: {x: 0.205, y: 0, z: 0.46000004}
m_LocalScale: {x: 0.31, y: 0.01, z: 0.14999999}
m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
m_Children:
- {fileID: 224000013285553920}
m_Father: {fileID: 4000013859835632}
- m_RootOrder: 11
+ m_RootOrder: 8
--- !u!4 &4000010541621026
Transform:
m_ObjectHideFlags: 1
@@ -907,34 +842,6 @@ Transform:
- {fileID: 224000013180048430}
m_Father: {fileID: 4000013859835632}
m_RootOrder: 4
---- !u!4 &4000011234500342
-Transform:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000012535845966}
- m_LocalRotation: {x: -0, y: -0, z: -0, w: 1}
- m_LocalPosition: {x: 0.195, y: 0.000000059604645, z: 0.46000007}
- m_LocalScale: {x: 0.14999999, y: 0.01, z: 0.14999999}
- m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
- m_Children:
- - {fileID: 224000010236752756}
- m_Father: {fileID: 4000013859835632}
- m_RootOrder: 9
---- !u!4 &4000011636982694
-Transform:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000010089480526}
- m_LocalRotation: {x: -0, y: -0, z: -0, w: 1}
- m_LocalPosition: {x: -0.105, y: 0, z: 0.46}
- m_LocalScale: {x: 0.15, y: 0.01, z: 0.15}
- m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
- m_Children:
- - {fileID: 224000010573683446}
- m_Father: {fileID: 4000013859835632}
- m_RootOrder: 7
--- !u!4 &4000011852492718
Transform:
m_ObjectHideFlags: 1
@@ -961,6 +868,7 @@ Transform:
m_Children:
- {fileID: 4000010234157170}
- {fileID: 4000011852492718}
+ - {fileID: 4000010068502200}
m_Father: {fileID: 4000013025176432}
m_RootOrder: 1
--- !u!4 &4000012326273044
@@ -977,20 +885,6 @@ Transform:
- {fileID: 224000011869463418}
m_Father: {fileID: 4000013859835632}
m_RootOrder: 6
---- !u!4 &4000012689466318
-Transform:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000010033919940}
- m_LocalRotation: {x: -0, y: -0, z: -0, w: 1}
- m_LocalPosition: {x: 0.04499996, y: 0.000000059604645, z: 0.46000007}
- m_LocalScale: {x: 0.14999999, y: 0.01, z: 0.14999999}
- m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
- m_Children:
- - {fileID: 224000013948607280}
- m_Father: {fileID: 4000013859835632}
- m_RootOrder: 8
--- !u!4 &4000013025176432
Transform:
m_ObjectHideFlags: 1
@@ -1015,7 +909,7 @@ Transform:
m_PrefabInternal: {fileID: 100100000}
m_GameObject: {fileID: 1000011821716180}
m_LocalRotation: {x: -0, y: -0, z: -0, w: 1}
- m_LocalPosition: {x: -1.06, y: 0, z: 0.06}
+ m_LocalPosition: {x: -0.98, y: 0, z: 0.56}
m_LocalScale: {x: 0.3, y: 0.01, z: 0.2}
m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
m_Children:
@@ -1029,8 +923,8 @@ Transform:
m_PrefabInternal: {fileID: 100100000}
m_GameObject: {fileID: 1000012747880360}
m_LocalRotation: {x: -0, y: -0, z: -0, w: 1}
- m_LocalPosition: {x: 0, y: -0.01, z: 0}
- m_LocalScale: {x: 1.5, y: 0.01, z: 0.75}
+ m_LocalPosition: {x: 0.125, y: 0, z: 0}
+ m_LocalScale: {x: 1.7, y: 0.2, z: 0.85}
m_LocalEulerAnglesHint: {x: -22.84, y: 0, z: 0}
m_Children: []
m_Father: {fileID: 4000013859835632}
@@ -1049,6 +943,19 @@ Transform:
- {fileID: 224000012435902802}
m_Father: {fileID: 4000013859835632}
m_RootOrder: 2
+--- !u!4 &4000013256322456
+Transform:
+ m_ObjectHideFlags: 1
+ m_PrefabParentObject: {fileID: 0}
+ m_PrefabInternal: {fileID: 100100000}
+ m_GameObject: {fileID: 1000013340159164}
+ m_LocalRotation: {x: -0, y: -0, z: -0, w: 1}
+ m_LocalPosition: {x: 0, y: -0.050000027, z: 0}
+ m_LocalScale: {x: 0.049999997, y: 0.049999997, z: 0.049999997}
+ m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
+ m_Children: []
+ m_Father: {fileID: 4000013722089028}
+ m_RootOrder: 2
--- !u!4 &4000013722089028
Transform:
m_ObjectHideFlags: 1
@@ -1062,6 +969,7 @@ Transform:
m_Children:
- {fileID: 4000013790136688}
- {fileID: 4000010968355626}
+ - {fileID: 4000013256322456}
m_Father: {fileID: 4000013025176432}
m_RootOrder: 2
--- !u!4 &4000013790136688
@@ -1095,9 +1003,6 @@ Transform:
- {fileID: 4000011067698962}
- {fileID: 4000013131268924}
- {fileID: 4000012326273044}
- - {fileID: 4000011636982694}
- - {fileID: 4000012689466318}
- - {fileID: 4000011234500342}
- {fileID: 4000010005528686}
- {fileID: 4000010256108328}
- {fileID: 4000010133606078}
@@ -1147,26 +1052,26 @@ MeshRenderer:
m_LightmapParameters: {fileID: 0}
m_SortingLayerID: 0
m_SortingOrder: 0
---- !u!23 &23000010025218198
+--- !u!23 &23000010034095974
MeshRenderer:
m_ObjectHideFlags: 1
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000010089480526}
+ m_GameObject: {fileID: 1000011464294290}
m_Enabled: 1
m_CastShadows: 0
- m_ReceiveShadows: 1
+ m_ReceiveShadows: 0
m_MotionVectors: 1
m_LightProbeUsage: 1
m_ReflectionProbeUsage: 1
m_Materials:
- - {fileID: 2100000, guid: 021552db260a9654ea7d9d472e44eb58, type: 2}
+ - {fileID: 2180264, guid: 715b80e429c437e40867928a4e1fc975, type: 2}
m_SubsetIndices:
m_StaticBatchRoot: {fileID: 0}
m_ProbeAnchor: {fileID: 0}
m_LightProbeVolumeOverride: {fileID: 0}
m_ScaleInLightmap: 1
- m_PreserveUVs: 1
+ m_PreserveUVs: 0
m_IgnoreNormalsForChartDetection: 0
m_ImportantGI: 0
m_SelectedWireframeHidden: 0
@@ -1176,26 +1081,26 @@ MeshRenderer:
m_LightmapParameters: {fileID: 0}
m_SortingLayerID: 0
m_SortingOrder: 0
---- !u!23 &23000010034095974
+--- !u!23 &23000010497004726
MeshRenderer:
m_ObjectHideFlags: 1
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000011464294290}
+ m_GameObject: {fileID: 1000011303481704}
m_Enabled: 1
m_CastShadows: 0
- m_ReceiveShadows: 0
+ m_ReceiveShadows: 1
m_MotionVectors: 1
m_LightProbeUsage: 1
m_ReflectionProbeUsage: 1
m_Materials:
- - {fileID: 2180264, guid: 715b80e429c437e40867928a4e1fc975, type: 2}
+ - {fileID: 2100000, guid: 021552db260a9654ea7d9d472e44eb58, type: 2}
m_SubsetIndices:
m_StaticBatchRoot: {fileID: 0}
m_ProbeAnchor: {fileID: 0}
m_LightProbeVolumeOverride: {fileID: 0}
m_ScaleInLightmap: 1
- m_PreserveUVs: 0
+ m_PreserveUVs: 1
m_IgnoreNormalsForChartDetection: 0
m_ImportantGI: 0
m_SelectedWireframeHidden: 0
@@ -1205,12 +1110,12 @@ MeshRenderer:
m_LightmapParameters: {fileID: 0}
m_SortingLayerID: 0
m_SortingOrder: 0
---- !u!23 &23000010311683274
+--- !u!23 &23000010512263608
MeshRenderer:
m_ObjectHideFlags: 1
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000012703070624}
+ m_GameObject: {fileID: 1000011403064836}
m_Enabled: 1
m_CastShadows: 0
m_ReceiveShadows: 0
@@ -1234,12 +1139,12 @@ MeshRenderer:
m_LightmapParameters: {fileID: 0}
m_SortingLayerID: 0
m_SortingOrder: 0
---- !u!23 &23000010407663374
+--- !u!23 &23000010701034032
MeshRenderer:
m_ObjectHideFlags: 1
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000012535845966}
+ m_GameObject: {fileID: 1000011692986572}
m_Enabled: 1
m_CastShadows: 0
m_ReceiveShadows: 1
@@ -1263,26 +1168,26 @@ MeshRenderer:
m_LightmapParameters: {fileID: 0}
m_SortingLayerID: 0
m_SortingOrder: 0
---- !u!23 &23000010497004726
+--- !u!23 &23000010902180540
MeshRenderer:
m_ObjectHideFlags: 1
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000011303481704}
+ m_GameObject: {fileID: 1000011740335272}
m_Enabled: 1
m_CastShadows: 0
- m_ReceiveShadows: 1
+ m_ReceiveShadows: 0
m_MotionVectors: 1
m_LightProbeUsage: 1
m_ReflectionProbeUsage: 1
m_Materials:
- - {fileID: 2100000, guid: 021552db260a9654ea7d9d472e44eb58, type: 2}
+ - {fileID: 2180264, guid: 715b80e429c437e40867928a4e1fc975, type: 2}
m_SubsetIndices:
m_StaticBatchRoot: {fileID: 0}
m_ProbeAnchor: {fileID: 0}
m_LightProbeVolumeOverride: {fileID: 0}
m_ScaleInLightmap: 1
- m_PreserveUVs: 1
+ m_PreserveUVs: 0
m_IgnoreNormalsForChartDetection: 0
m_ImportantGI: 0
m_SelectedWireframeHidden: 0
@@ -1292,12 +1197,12 @@ MeshRenderer:
m_LightmapParameters: {fileID: 0}
m_SortingLayerID: 0
m_SortingOrder: 0
---- !u!23 &23000010512263608
+--- !u!23 &23000011065239064
MeshRenderer:
m_ObjectHideFlags: 1
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000011403064836}
+ m_GameObject: {fileID: 1000011590471936}
m_Enabled: 1
m_CastShadows: 0
m_ReceiveShadows: 0
@@ -1321,20 +1226,20 @@ MeshRenderer:
m_LightmapParameters: {fileID: 0}
m_SortingLayerID: 0
m_SortingOrder: 0
---- !u!23 &23000010536738872
+--- !u!23 &23000011162298744
MeshRenderer:
m_ObjectHideFlags: 1
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000012747880360}
+ m_GameObject: {fileID: 1000010615748202}
m_Enabled: 1
- m_CastShadows: 0
+ m_CastShadows: 1
m_ReceiveShadows: 0
- m_MotionVectors: 0
+ m_MotionVectors: 1
m_LightProbeUsage: 1
m_ReflectionProbeUsage: 1
m_Materials:
- - {fileID: 2100000, guid: 55f2d017b57e3b14aa7421b691236b64, type: 2}
+ - {fileID: 10303, guid: 0000000000000000f000000000000000, type: 0}
m_SubsetIndices:
m_StaticBatchRoot: {fileID: 0}
m_ProbeAnchor: {fileID: 0}
@@ -1350,12 +1255,12 @@ MeshRenderer:
m_LightmapParameters: {fileID: 0}
m_SortingLayerID: 0
m_SortingOrder: 0
---- !u!23 &23000010701034032
+--- !u!23 &23000011498129376
MeshRenderer:
m_ObjectHideFlags: 1
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000011692986572}
+ m_GameObject: {fileID: 1000010243209718}
m_Enabled: 1
m_CastShadows: 0
m_ReceiveShadows: 1
@@ -1379,26 +1284,26 @@ MeshRenderer:
m_LightmapParameters: {fileID: 0}
m_SortingLayerID: 0
m_SortingOrder: 0
---- !u!23 &23000010809721506
+--- !u!23 &23000011897981684
MeshRenderer:
m_ObjectHideFlags: 1
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000010412975446}
+ m_GameObject: {fileID: 1000011322283204}
m_Enabled: 1
m_CastShadows: 0
- m_ReceiveShadows: 0
+ m_ReceiveShadows: 1
m_MotionVectors: 1
m_LightProbeUsage: 1
m_ReflectionProbeUsage: 1
m_Materials:
- - {fileID: 2180264, guid: 715b80e429c437e40867928a4e1fc975, type: 2}
+ - {fileID: 2100000, guid: 021552db260a9654ea7d9d472e44eb58, type: 2}
m_SubsetIndices:
m_StaticBatchRoot: {fileID: 0}
m_ProbeAnchor: {fileID: 0}
m_LightProbeVolumeOverride: {fileID: 0}
m_ScaleInLightmap: 1
- m_PreserveUVs: 0
+ m_PreserveUVs: 1
m_IgnoreNormalsForChartDetection: 0
m_ImportantGI: 0
m_SelectedWireframeHidden: 0
@@ -1408,26 +1313,26 @@ MeshRenderer:
m_LightmapParameters: {fileID: 0}
m_SortingLayerID: 0
m_SortingOrder: 0
---- !u!23 &23000010902180540
+--- !u!23 &23000012001671646
MeshRenderer:
m_ObjectHideFlags: 1
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000011740335272}
+ m_GameObject: {fileID: 1000012217403784}
m_Enabled: 1
- m_CastShadows: 0
+ m_CastShadows: 1
m_ReceiveShadows: 0
m_MotionVectors: 1
m_LightProbeUsage: 1
m_ReflectionProbeUsage: 1
m_Materials:
- - {fileID: 2180264, guid: 715b80e429c437e40867928a4e1fc975, type: 2}
+ - {fileID: 10303, guid: 0000000000000000f000000000000000, type: 0}
m_SubsetIndices:
m_StaticBatchRoot: {fileID: 0}
m_ProbeAnchor: {fileID: 0}
m_LightProbeVolumeOverride: {fileID: 0}
m_ScaleInLightmap: 1
- m_PreserveUVs: 0
+ m_PreserveUVs: 1
m_IgnoreNormalsForChartDetection: 0
m_ImportantGI: 0
m_SelectedWireframeHidden: 0
@@ -1437,26 +1342,26 @@ MeshRenderer:
m_LightmapParameters: {fileID: 0}
m_SortingLayerID: 0
m_SortingOrder: 0
---- !u!23 &23000011065239064
+--- !u!23 &23000012082499760
MeshRenderer:
m_ObjectHideFlags: 1
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000011590471936}
+ m_GameObject: {fileID: 1000012262115348}
m_Enabled: 1
m_CastShadows: 0
- m_ReceiveShadows: 0
+ m_ReceiveShadows: 1
m_MotionVectors: 1
m_LightProbeUsage: 1
m_ReflectionProbeUsage: 1
m_Materials:
- - {fileID: 2180264, guid: 715b80e429c437e40867928a4e1fc975, type: 2}
+ - {fileID: 2100000, guid: 021552db260a9654ea7d9d472e44eb58, type: 2}
m_SubsetIndices:
m_StaticBatchRoot: {fileID: 0}
m_ProbeAnchor: {fileID: 0}
m_LightProbeVolumeOverride: {fileID: 0}
m_ScaleInLightmap: 1
- m_PreserveUVs: 0
+ m_PreserveUVs: 1
m_IgnoreNormalsForChartDetection: 0
m_ImportantGI: 0
m_SelectedWireframeHidden: 0
@@ -1466,12 +1371,12 @@ MeshRenderer:
m_LightmapParameters: {fileID: 0}
m_SortingLayerID: 0
m_SortingOrder: 0
---- !u!23 &23000011162298744
+--- !u!23 &23000012371671870
MeshRenderer:
m_ObjectHideFlags: 1
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000010615748202}
+ m_GameObject: {fileID: 1000011932752296}
m_Enabled: 1
m_CastShadows: 1
m_ReceiveShadows: 0
@@ -1495,26 +1400,26 @@ MeshRenderer:
m_LightmapParameters: {fileID: 0}
m_SortingLayerID: 0
m_SortingOrder: 0
---- !u!23 &23000011467883974
+--- !u!23 &23000012556946724
MeshRenderer:
m_ObjectHideFlags: 1
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000010033919940}
+ m_GameObject: {fileID: 1000012959594796}
m_Enabled: 1
m_CastShadows: 0
- m_ReceiveShadows: 1
+ m_ReceiveShadows: 0
m_MotionVectors: 1
m_LightProbeUsage: 1
m_ReflectionProbeUsage: 1
m_Materials:
- - {fileID: 2100000, guid: 021552db260a9654ea7d9d472e44eb58, type: 2}
+ - {fileID: 2180264, guid: 715b80e429c437e40867928a4e1fc975, type: 2}
m_SubsetIndices:
m_StaticBatchRoot: {fileID: 0}
m_ProbeAnchor: {fileID: 0}
m_LightProbeVolumeOverride: {fileID: 0}
m_ScaleInLightmap: 1
- m_PreserveUVs: 1
+ m_PreserveUVs: 0
m_IgnoreNormalsForChartDetection: 0
m_ImportantGI: 0
m_SelectedWireframeHidden: 0
@@ -1524,12 +1429,12 @@ MeshRenderer:
m_LightmapParameters: {fileID: 0}
m_SortingLayerID: 0
m_SortingOrder: 0
---- !u!23 &23000011498129376
+--- !u!23 &23000012735156350
MeshRenderer:
m_ObjectHideFlags: 1
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000010243209718}
+ m_GameObject: {fileID: 1000010921968412}
m_Enabled: 1
m_CastShadows: 0
m_ReceiveShadows: 1
@@ -1553,12 +1458,12 @@ MeshRenderer:
m_LightmapParameters: {fileID: 0}
m_SortingLayerID: 0
m_SortingOrder: 0
---- !u!23 &23000011897981684
+--- !u!23 &23000012842008522
MeshRenderer:
m_ObjectHideFlags: 1
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000011322283204}
+ m_GameObject: {fileID: 1000013267824754}
m_Enabled: 1
m_CastShadows: 0
m_ReceiveShadows: 1
@@ -1582,20 +1487,20 @@ MeshRenderer:
m_LightmapParameters: {fileID: 0}
m_SortingLayerID: 0
m_SortingOrder: 0
---- !u!23 &23000012001671646
+--- !u!23 &23000012995747048
MeshRenderer:
m_ObjectHideFlags: 1
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000012217403784}
+ m_GameObject: {fileID: 1000011821716180}
m_Enabled: 1
- m_CastShadows: 1
- m_ReceiveShadows: 0
+ m_CastShadows: 0
+ m_ReceiveShadows: 1
m_MotionVectors: 1
m_LightProbeUsage: 1
m_ReflectionProbeUsage: 1
m_Materials:
- - {fileID: 10303, guid: 0000000000000000f000000000000000, type: 0}
+ - {fileID: 2100000, guid: 021552db260a9654ea7d9d472e44eb58, type: 2}
m_SubsetIndices:
m_StaticBatchRoot: {fileID: 0}
m_ProbeAnchor: {fileID: 0}
@@ -1611,12 +1516,12 @@ MeshRenderer:
m_LightmapParameters: {fileID: 0}
m_SortingLayerID: 0
m_SortingOrder: 0
---- !u!23 &23000012023175106
+--- !u!23 &23000013224571874
MeshRenderer:
m_ObjectHideFlags: 1
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000012063527344}
+ m_GameObject: {fileID: 1000013364588658}
m_Enabled: 1
m_CastShadows: 0
m_ReceiveShadows: 0
@@ -1640,218 +1545,15 @@ MeshRenderer:
m_LightmapParameters: {fileID: 0}
m_SortingLayerID: 0
m_SortingOrder: 0
---- !u!23 &23000012082499760
+--- !u!23 &23000013237804212
MeshRenderer:
m_ObjectHideFlags: 1
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000012262115348}
+ m_GameObject: {fileID: 1000012589486870}
m_Enabled: 1
m_CastShadows: 0
- m_ReceiveShadows: 1
- m_MotionVectors: 1
- m_LightProbeUsage: 1
- m_ReflectionProbeUsage: 1
- m_Materials:
- - {fileID: 2100000, guid: 021552db260a9654ea7d9d472e44eb58, type: 2}
- m_SubsetIndices:
- m_StaticBatchRoot: {fileID: 0}
- m_ProbeAnchor: {fileID: 0}
- m_LightProbeVolumeOverride: {fileID: 0}
- m_ScaleInLightmap: 1
- m_PreserveUVs: 1
- m_IgnoreNormalsForChartDetection: 0
- m_ImportantGI: 0
- m_SelectedWireframeHidden: 0
- m_MinimumChartSize: 4
- m_AutoUVMaxDistance: 0.5
- m_AutoUVMaxAngle: 89
- m_LightmapParameters: {fileID: 0}
- m_SortingLayerID: 0
- m_SortingOrder: 0
---- !u!23 &23000012371671870
-MeshRenderer:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000011932752296}
- m_Enabled: 1
- m_CastShadows: 1
- m_ReceiveShadows: 0
- m_MotionVectors: 1
- m_LightProbeUsage: 1
- m_ReflectionProbeUsage: 1
- m_Materials:
- - {fileID: 10303, guid: 0000000000000000f000000000000000, type: 0}
- m_SubsetIndices:
- m_StaticBatchRoot: {fileID: 0}
- m_ProbeAnchor: {fileID: 0}
- m_LightProbeVolumeOverride: {fileID: 0}
- m_ScaleInLightmap: 1
- m_PreserveUVs: 1
- m_IgnoreNormalsForChartDetection: 0
- m_ImportantGI: 0
- m_SelectedWireframeHidden: 0
- m_MinimumChartSize: 4
- m_AutoUVMaxDistance: 0.5
- m_AutoUVMaxAngle: 89
- m_LightmapParameters: {fileID: 0}
- m_SortingLayerID: 0
- m_SortingOrder: 0
---- !u!23 &23000012556946724
-MeshRenderer:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000012959594796}
- m_Enabled: 1
- m_CastShadows: 0
- m_ReceiveShadows: 0
- m_MotionVectors: 1
- m_LightProbeUsage: 1
- m_ReflectionProbeUsage: 1
- m_Materials:
- - {fileID: 2180264, guid: 715b80e429c437e40867928a4e1fc975, type: 2}
- m_SubsetIndices:
- m_StaticBatchRoot: {fileID: 0}
- m_ProbeAnchor: {fileID: 0}
- m_LightProbeVolumeOverride: {fileID: 0}
- m_ScaleInLightmap: 1
- m_PreserveUVs: 0
- m_IgnoreNormalsForChartDetection: 0
- m_ImportantGI: 0
- m_SelectedWireframeHidden: 0
- m_MinimumChartSize: 4
- m_AutoUVMaxDistance: 0.5
- m_AutoUVMaxAngle: 89
- m_LightmapParameters: {fileID: 0}
- m_SortingLayerID: 0
- m_SortingOrder: 0
---- !u!23 &23000012735156350
-MeshRenderer:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000010921968412}
- m_Enabled: 1
- m_CastShadows: 0
- m_ReceiveShadows: 1
- m_MotionVectors: 1
- m_LightProbeUsage: 1
- m_ReflectionProbeUsage: 1
- m_Materials:
- - {fileID: 2100000, guid: 021552db260a9654ea7d9d472e44eb58, type: 2}
- m_SubsetIndices:
- m_StaticBatchRoot: {fileID: 0}
- m_ProbeAnchor: {fileID: 0}
- m_LightProbeVolumeOverride: {fileID: 0}
- m_ScaleInLightmap: 1
- m_PreserveUVs: 1
- m_IgnoreNormalsForChartDetection: 0
- m_ImportantGI: 0
- m_SelectedWireframeHidden: 0
- m_MinimumChartSize: 4
- m_AutoUVMaxDistance: 0.5
- m_AutoUVMaxAngle: 89
- m_LightmapParameters: {fileID: 0}
- m_SortingLayerID: 0
- m_SortingOrder: 0
---- !u!23 &23000012842008522
-MeshRenderer:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000013267824754}
- m_Enabled: 1
- m_CastShadows: 0
- m_ReceiveShadows: 1
- m_MotionVectors: 1
- m_LightProbeUsage: 1
- m_ReflectionProbeUsage: 1
- m_Materials:
- - {fileID: 2100000, guid: 021552db260a9654ea7d9d472e44eb58, type: 2}
- m_SubsetIndices:
- m_StaticBatchRoot: {fileID: 0}
- m_ProbeAnchor: {fileID: 0}
- m_LightProbeVolumeOverride: {fileID: 0}
- m_ScaleInLightmap: 1
- m_PreserveUVs: 1
- m_IgnoreNormalsForChartDetection: 0
- m_ImportantGI: 0
- m_SelectedWireframeHidden: 0
- m_MinimumChartSize: 4
- m_AutoUVMaxDistance: 0.5
- m_AutoUVMaxAngle: 89
- m_LightmapParameters: {fileID: 0}
- m_SortingLayerID: 0
- m_SortingOrder: 0
---- !u!23 &23000012995747048
-MeshRenderer:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000011821716180}
- m_Enabled: 1
- m_CastShadows: 0
- m_ReceiveShadows: 1
- m_MotionVectors: 1
- m_LightProbeUsage: 1
- m_ReflectionProbeUsage: 1
- m_Materials:
- - {fileID: 2100000, guid: 021552db260a9654ea7d9d472e44eb58, type: 2}
- m_SubsetIndices:
- m_StaticBatchRoot: {fileID: 0}
- m_ProbeAnchor: {fileID: 0}
- m_LightProbeVolumeOverride: {fileID: 0}
- m_ScaleInLightmap: 1
- m_PreserveUVs: 1
- m_IgnoreNormalsForChartDetection: 0
- m_ImportantGI: 0
- m_SelectedWireframeHidden: 0
- m_MinimumChartSize: 4
- m_AutoUVMaxDistance: 0.5
- m_AutoUVMaxAngle: 89
- m_LightmapParameters: {fileID: 0}
- m_SortingLayerID: 0
- m_SortingOrder: 0
---- !u!23 &23000013224571874
-MeshRenderer:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000013364588658}
- m_Enabled: 1
- m_CastShadows: 0
- m_ReceiveShadows: 0
- m_MotionVectors: 1
- m_LightProbeUsage: 1
- m_ReflectionProbeUsage: 1
- m_Materials:
- - {fileID: 2180264, guid: 715b80e429c437e40867928a4e1fc975, type: 2}
- m_SubsetIndices:
- m_StaticBatchRoot: {fileID: 0}
- m_ProbeAnchor: {fileID: 0}
- m_LightProbeVolumeOverride: {fileID: 0}
- m_ScaleInLightmap: 1
- m_PreserveUVs: 0
- m_IgnoreNormalsForChartDetection: 0
- m_ImportantGI: 0
- m_SelectedWireframeHidden: 0
- m_MinimumChartSize: 4
- m_AutoUVMaxDistance: 0.5
- m_AutoUVMaxAngle: 89
- m_LightmapParameters: {fileID: 0}
- m_SortingLayerID: 0
- m_SortingOrder: 0
---- !u!23 &23000013237804212
-MeshRenderer:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000012589486870}
- m_Enabled: 1
- m_CastShadows: 0
- m_ReceiveShadows: 0
+ m_ReceiveShadows: 0
m_MotionVectors: 1
m_LightProbeUsage: 1
m_ReflectionProbeUsage: 1
@@ -1995,13 +1697,6 @@ MeshFilter:
m_PrefabInternal: {fileID: 100100000}
m_GameObject: {fileID: 1000013834598524}
m_Mesh: {fileID: 0}
---- !u!33 &33000010091403864
-MeshFilter:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000012535845966}
- m_Mesh: {fileID: 10202, guid: 0000000000000000e000000000000000, type: 0}
--- !u!33 &33000010119433598
MeshFilter:
m_ObjectHideFlags: 1
@@ -2051,12 +1746,12 @@ MeshFilter:
m_PrefabInternal: {fileID: 100100000}
m_GameObject: {fileID: 1000011590471936}
m_Mesh: {fileID: 0}
---- !u!33 &33000011144877132
+--- !u!33 &33000011132834486
MeshFilter:
m_ObjectHideFlags: 1
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000010089480526}
+ m_GameObject: {fileID: 1000013340159164}
m_Mesh: {fileID: 10202, guid: 0000000000000000e000000000000000, type: 0}
--- !u!33 &33000011239244816
MeshFilter:
@@ -2079,13 +1774,6 @@ MeshFilter:
m_PrefabInternal: {fileID: 100100000}
m_GameObject: {fileID: 1000012747880360}
m_Mesh: {fileID: 10202, guid: 0000000000000000e000000000000000, type: 0}
---- !u!33 &33000011401375976
-MeshFilter:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000010412975446}
- m_Mesh: {fileID: 0}
--- !u!33 &33000011629607292
MeshFilter:
m_ObjectHideFlags: 1
@@ -2093,13 +1781,6 @@ MeshFilter:
m_PrefabInternal: {fileID: 100100000}
m_GameObject: {fileID: 1000011322283204}
m_Mesh: {fileID: 10202, guid: 0000000000000000e000000000000000, type: 0}
---- !u!33 &33000011880972442
-MeshFilter:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000010033919940}
- m_Mesh: {fileID: 10202, guid: 0000000000000000e000000000000000, type: 0}
--- !u!33 &33000012119288656
MeshFilter:
m_ObjectHideFlags: 1
@@ -2107,13 +1788,6 @@ MeshFilter:
m_PrefabInternal: {fileID: 100100000}
m_GameObject: {fileID: 1000011821716180}
m_Mesh: {fileID: 10202, guid: 0000000000000000e000000000000000, type: 0}
---- !u!33 &33000012290704998
-MeshFilter:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000012063527344}
- m_Mesh: {fileID: 0}
--- !u!33 &33000012358895456
MeshFilter:
m_ObjectHideFlags: 1
@@ -2128,6 +1802,13 @@ MeshFilter:
m_PrefabInternal: {fileID: 100100000}
m_GameObject: {fileID: 1000012589486870}
m_Mesh: {fileID: 0}
+--- !u!33 &33000012690690984
+MeshFilter:
+ m_ObjectHideFlags: 1
+ m_PrefabParentObject: {fileID: 0}
+ m_PrefabInternal: {fileID: 100100000}
+ m_GameObject: {fileID: 1000010174852680}
+ m_Mesh: {fileID: 10202, guid: 0000000000000000e000000000000000, type: 0}
--- !u!33 &33000012726637334
MeshFilter:
m_ObjectHideFlags: 1
@@ -2170,13 +1851,6 @@ MeshFilter:
m_PrefabInternal: {fileID: 100100000}
m_GameObject: {fileID: 1000011403064836}
m_Mesh: {fileID: 0}
---- !u!33 &33000013801103796
-MeshFilter:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000012703070624}
- m_Mesh: {fileID: 0}
--- !u!33 &33000013853862454
MeshFilter:
m_ObjectHideFlags: 1
@@ -2198,24 +1872,24 @@ MeshFilter:
m_PrefabInternal: {fileID: 100100000}
m_GameObject: {fileID: 1000012217403784}
m_Mesh: {fileID: 10207, guid: 0000000000000000e000000000000000, type: 0}
---- !u!65 &65000010635511752
+--- !u!65 &65000010632855888
BoxCollider:
m_ObjectHideFlags: 1
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000011303481704}
+ m_GameObject: {fileID: 1000013340159164}
m_Material: {fileID: 0}
- m_IsTrigger: 0
+ m_IsTrigger: 1
m_Enabled: 1
serializedVersion: 2
- m_Size: {x: 1, y: 5, z: 1}
- m_Center: {x: 0, y: -2, z: 0}
---- !u!65 &65000010893494936
+ m_Size: {x: 1, y: 1, z: 1}
+ m_Center: {x: 0, y: 0, z: 0}
+--- !u!65 &65000010635511752
BoxCollider:
m_ObjectHideFlags: 1
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000010089480526}
+ m_GameObject: {fileID: 1000011303481704}
m_Material: {fileID: 0}
m_IsTrigger: 0
m_Enabled: 1
@@ -2246,18 +1920,6 @@ BoxCollider:
serializedVersion: 2
m_Size: {x: 1, y: 5, z: 1}
m_Center: {x: 0, y: -2, z: 0}
---- !u!65 &65000011503203434
-BoxCollider:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000010033919940}
- m_Material: {fileID: 0}
- m_IsTrigger: 0
- m_Enabled: 1
- serializedVersion: 2
- m_Size: {x: 1, y: 5, z: 1}
- m_Center: {x: 0, y: -2, z: 0}
--- !u!65 &65000011670270054
BoxCollider:
m_ObjectHideFlags: 1
@@ -2294,24 +1956,24 @@ BoxCollider:
serializedVersion: 2
m_Size: {x: 1, y: 5, z: 1}
m_Center: {x: 0, y: -2, z: 0}
---- !u!65 &65000012433588288
+--- !u!65 &65000012333261654
BoxCollider:
m_ObjectHideFlags: 1
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000011322283204}
+ m_GameObject: {fileID: 1000010174852680}
m_Material: {fileID: 0}
- m_IsTrigger: 0
+ m_IsTrigger: 1
m_Enabled: 1
serializedVersion: 2
- m_Size: {x: 1, y: 5, z: 1}
- m_Center: {x: 0, y: -2, z: 0}
---- !u!65 &65000012762395060
+ m_Size: {x: 1, y: 1, z: 1}
+ m_Center: {x: 0, y: 0, z: 0}
+--- !u!65 &65000012433588288
BoxCollider:
m_ObjectHideFlags: 1
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000012535845966}
+ m_GameObject: {fileID: 1000011322283204}
m_Material: {fileID: 0}
m_IsTrigger: 0
m_Enabled: 1
@@ -2762,185 +2424,30 @@ MonoBehaviour:
m_isInputParsingRequired: 1
m_inputSource: 0
m_hasFontAssetChanged: 0
- m_subTextObjects:
- - {fileID: 0}
- - {fileID: 0}
- - {fileID: 0}
- - {fileID: 0}
- - {fileID: 0}
- - {fileID: 0}
- - {fileID: 0}
- - {fileID: 0}
- m_baseMaterial: {fileID: 0}
- m_maskOffset: {x: 0, y: 0, z: 0, w: 0}
---- !u!114 &114000010748070872
-MonoBehaviour:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000013080610010}
- m_Enabled: 1
- m_EditorHideFlags: 0
- m_Script: {fileID: 11500000, guid: e5bbaf25e7301ed44b25199adaa35026, type: 3}
- m_Name:
- m_EditorClassIdentifier:
- keyboard: {fileID: 114000011813929276}
- label: {fileID: 114000012530348626}
- inactiveMat: {fileID: 2100000, guid: 021552db260a9654ea7d9d472e44eb58, type: 2}
- activeMat: {fileID: 2100000, guid: 157abfb689445624c97d685110ed6172, type: 2}
- disabledMat: {fileID: 2100000, guid: 05726c44b31fc344db9d054567e02ee4, type: 2}
- defaultPosition: {x: 0, y: 0, z: 0}
- pressedPosition: {x: 0, y: 0, z: 0}
- pressDirection: {x: 0, y: -1, z: 0}
- pressMagnitude: 0.1
- autoInit: 1
---- !u!114 &114000010799792276
-MonoBehaviour:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000012959594796}
- m_Enabled: 1
- m_EditorHideFlags: 0
- m_Script: {fileID: -806885394, guid: b5bd0d848a86e48409fe56688d66ecb5, type: 3}
- m_Name:
- m_EditorClassIdentifier:
- m_Material: {fileID: 0}
- m_Color: {r: 1, g: 1, b: 1, a: 1}
- m_RaycastTarget: 1
- m_OnCullStateChanged:
- m_PersistentCalls:
- m_Calls: []
- m_TypeName: UnityEngine.UI.MaskableGraphic+CullStateChangedEvent, UnityEngine.UI,
- Version=1.0.0.0, Culture=neutral, PublicKeyToken=null
- m_text: 1
- m_isRightToLeft: 0
- m_fontAsset: {fileID: 11400000, guid: 715b80e429c437e40867928a4e1fc975, type: 2}
- m_sharedMaterial: {fileID: 2180264, guid: 715b80e429c437e40867928a4e1fc975, type: 2}
- m_fontSharedMaterials: []
- m_fontMaterial: {fileID: 0}
- m_fontMaterials: []
- m_fontColor32:
- serializedVersion: 2
- rgba: 4279505940
- m_fontColor: {r: 0.08088237, g: 0.08088237, b: 0.08088237, a: 1}
- m_enableVertexGradient: 0
- m_fontColorGradient:
- topLeft: {r: 1, g: 1, b: 1, a: 1}
- topRight: {r: 1, g: 1, b: 1, a: 1}
- bottomLeft: {r: 1, g: 1, b: 1, a: 1}
- bottomRight: {r: 1, g: 1, b: 1, a: 1}
- m_fontColorGradientPreset: {fileID: 0}
- m_spriteAsset: {fileID: 0}
- m_tintAllSprites: 0
- m_overrideHtmlColors: 0
- m_faceColor:
- serializedVersion: 2
- rgba: 4294967295
- m_outlineColor:
- serializedVersion: 2
- rgba: 4278190080
- m_fontSize: 7
- m_fontSizeBase: 7
- m_fontWeight: 400
- m_enableAutoSizing: 0
- m_fontSizeMin: 18
- m_fontSizeMax: 72
- m_fontStyle: 0
- m_textAlignment: 514
- m_isAlignmentEnumConverted: 1
- m_characterSpacing: 0
- m_wordSpacing: 0
- m_lineSpacing: 0
- m_lineSpacingMax: 0
- m_paragraphSpacing: 0
- m_charWidthMaxAdj: 0
- m_enableWordWrapping: 1
- m_wordWrappingRatios: 0.4
- m_overflowMode: 0
- m_firstOverflowCharacterIndex: -1
- m_linkedTextComponent: {fileID: 0}
- m_isLinkedTextComponent: 0
- m_enableKerning: 1
- m_enableExtraPadding: 0
- checkPaddingRequired: 0
- m_isRichText: 1
- m_parseCtrlCharacters: 1
- m_isOrthographic: 0
- m_isCullingEnabled: 0
- m_ignoreRectMaskCulling: 0
- m_ignoreCulling: 1
- m_horizontalMapping: 0
- m_verticalMapping: 0
- m_uvLineOffset: 0
- m_geometrySortingOrder: 0
- m_firstVisibleCharacter: 0
- m_useMaxVisibleDescender: 1
- m_pageToDisplay: 1
- m_margin: {x: 0, y: 0, z: 0, w: 0}
- m_textInfo:
- textComponent: {fileID: 114000010799792276}
- characterCount: 1
- spriteCount: 0
- spaceCount: 0
- wordCount: 1
- linkCount: 0
- lineCount: 1
- pageCount: 1
- materialCount: 1
- m_havePropertiesChanged: 1
- m_isUsingLegacyAnimationComponent: 0
- m_isVolumetricText: 0
- m_spriteAnimator: {fileID: 0}
- m_isInputParsingRequired: 1
- m_inputSource: 0
- m_hasFontAssetChanged: 0
- m_renderer: {fileID: 23000012556946724}
- m_subTextObjects:
- - {fileID: 0}
- - {fileID: 0}
- - {fileID: 0}
- - {fileID: 0}
- - {fileID: 0}
- - {fileID: 0}
- - {fileID: 0}
- - {fileID: 0}
- m_maskType: 0
---- !u!114 &114000010924209110
-MonoBehaviour:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000010033919940}
- m_Enabled: 1
- m_EditorHideFlags: 0
- m_Script: {fileID: 11500000, guid: c16caca778364914aa98ebe1f690817a, type: 3}
- m_Name:
- m_EditorClassIdentifier:
- keyboard: {fileID: 114000011813929276}
- label: {fileID: 114000012236845518}
- inactiveMat: {fileID: 2100000, guid: 021552db260a9654ea7d9d472e44eb58, type: 2}
- activeMat: {fileID: 2100000, guid: 157abfb689445624c97d685110ed6172, type: 2}
- disabledMat: {fileID: 2100000, guid: 05726c44b31fc344db9d054567e02ee4, type: 2}
- defaultPosition: {x: 0, y: 0, z: 0}
- pressedPosition: {x: 0, y: 0, z: 0}
- pressDirection: {x: 0, y: -1, z: 0}
- pressMagnitude: 0.1
- autoInit: 1
- size: 2
---- !u!114 &114000010936285556
+ m_subTextObjects:
+ - {fileID: 0}
+ - {fileID: 0}
+ - {fileID: 0}
+ - {fileID: 0}
+ - {fileID: 0}
+ - {fileID: 0}
+ - {fileID: 0}
+ - {fileID: 0}
+ m_baseMaterial: {fileID: 0}
+ m_maskOffset: {x: 0, y: 0, z: 0, w: 0}
+--- !u!114 &114000010748070872
MonoBehaviour:
m_ObjectHideFlags: 1
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000010243209718}
+ m_GameObject: {fileID: 1000013080610010}
m_Enabled: 1
m_EditorHideFlags: 0
- m_Script: {fileID: 11500000, guid: 20ad569dfefda984ba68d50f80e17926, type: 3}
+ m_Script: {fileID: 11500000, guid: e5bbaf25e7301ed44b25199adaa35026, type: 3}
m_Name:
m_EditorClassIdentifier:
keyboard: {fileID: 114000011813929276}
- label: {fileID: 114000014124921810}
+ label: {fileID: 114000012530348626}
inactiveMat: {fileID: 2100000, guid: 021552db260a9654ea7d9d472e44eb58, type: 2}
activeMat: {fileID: 2100000, guid: 157abfb689445624c97d685110ed6172, type: 2}
disabledMat: {fileID: 2100000, guid: 05726c44b31fc344db9d054567e02ee4, type: 2}
@@ -2949,12 +2456,12 @@ MonoBehaviour:
pressDirection: {x: 0, y: -1, z: 0}
pressMagnitude: 0.1
autoInit: 1
---- !u!114 &114000011040958896
+--- !u!114 &114000010799792276
MonoBehaviour:
m_ObjectHideFlags: 1
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000012703070624}
+ m_GameObject: {fileID: 1000012959594796}
m_Enabled: 1
m_EditorHideFlags: 0
m_Script: {fileID: -806885394, guid: b5bd0d848a86e48409fe56688d66ecb5, type: 3}
@@ -2968,7 +2475,7 @@ MonoBehaviour:
m_Calls: []
m_TypeName: UnityEngine.UI.MaskableGraphic+CullStateChangedEvent, UnityEngine.UI,
Version=1.0.0.0, Culture=neutral, PublicKeyToken=null
- m_text: L
+ m_text: 1
m_isRightToLeft: 0
m_fontAsset: {fileID: 11400000, guid: 715b80e429c437e40867928a4e1fc975, type: 2}
m_sharedMaterial: {fileID: 2180264, guid: 715b80e429c437e40867928a4e1fc975, type: 2}
@@ -3034,7 +2541,7 @@ MonoBehaviour:
m_pageToDisplay: 1
m_margin: {x: 0, y: 0, z: 0, w: 0}
m_textInfo:
- textComponent: {fileID: 114000011040958896}
+ textComponent: {fileID: 114000010799792276}
characterCount: 1
spriteCount: 0
spaceCount: 0
@@ -3050,7 +2557,7 @@ MonoBehaviour:
m_isInputParsingRequired: 1
m_inputSource: 0
m_hasFontAssetChanged: 0
- m_renderer: {fileID: 23000010311683274}
+ m_renderer: {fileID: 23000012556946724}
m_subTextObjects:
- {fileID: 0}
- {fileID: 0}
@@ -3061,6 +2568,40 @@ MonoBehaviour:
- {fileID: 0}
- {fileID: 0}
m_maskType: 0
+--- !u!114 &114000010912951870
+MonoBehaviour:
+ m_ObjectHideFlags: 1
+ m_PrefabParentObject: {fileID: 0}
+ m_PrefabInternal: {fileID: 100100000}
+ m_GameObject: {fileID: 1000010174852680}
+ m_Enabled: 1
+ m_EditorHideFlags: 0
+ m_Script: {fileID: 11500000, guid: 10db60974c6c8b145bf8a61883659e98, type: 3}
+ m_Name:
+ m_EditorClassIdentifier:
+ mallet: {fileID: 114000012984897716}
+ inKeyboard: 0
+--- !u!114 &114000010936285556
+MonoBehaviour:
+ m_ObjectHideFlags: 1
+ m_PrefabParentObject: {fileID: 0}
+ m_PrefabInternal: {fileID: 100100000}
+ m_GameObject: {fileID: 1000010243209718}
+ m_Enabled: 1
+ m_EditorHideFlags: 0
+ m_Script: {fileID: 11500000, guid: 20ad569dfefda984ba68d50f80e17926, type: 3}
+ m_Name:
+ m_EditorClassIdentifier:
+ keyboard: {fileID: 114000011813929276}
+ label: {fileID: 114000014124921810}
+ inactiveMat: {fileID: 2100000, guid: 021552db260a9654ea7d9d472e44eb58, type: 2}
+ activeMat: {fileID: 2100000, guid: 157abfb689445624c97d685110ed6172, type: 2}
+ disabledMat: {fileID: 2100000, guid: 05726c44b31fc344db9d054567e02ee4, type: 2}
+ defaultPosition: {x: 0, y: 0, z: 0}
+ pressedPosition: {x: 0, y: 0, z: 0}
+ pressDirection: {x: 0, y: -1, z: 0}
+ pressMagnitude: 0.1
+ autoInit: 1
--- !u!114 &114000011155968924
MonoBehaviour:
m_ObjectHideFlags: 1
@@ -3234,6 +2775,7 @@ MonoBehaviour:
m_EditorClassIdentifier:
clipToPlay: {fileID: 8300000, guid: 3432185da42c61f4aa9e8c9da931dd8e, type: 3}
hand: 1
+ handCollider: {fileID: 114000013318402454}
--- !u!114 &114000011388484120
MonoBehaviour:
m_ObjectHideFlags: 1
@@ -3346,28 +2888,6 @@ MonoBehaviour:
- {fileID: 0}
m_baseMaterial: {fileID: 0}
m_maskOffset: {x: 0, y: 0, z: 0, w: 0}
---- !u!114 &114000011431146602
-MonoBehaviour:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000012535845966}
- m_Enabled: 1
- m_EditorHideFlags: 0
- m_Script: {fileID: 11500000, guid: c16caca778364914aa98ebe1f690817a, type: 3}
- m_Name:
- m_EditorClassIdentifier:
- keyboard: {fileID: 114000011813929276}
- label: {fileID: 114000011040958896}
- inactiveMat: {fileID: 2100000, guid: 021552db260a9654ea7d9d472e44eb58, type: 2}
- activeMat: {fileID: 2100000, guid: 157abfb689445624c97d685110ed6172, type: 2}
- disabledMat: {fileID: 2100000, guid: 05726c44b31fc344db9d054567e02ee4, type: 2}
- defaultPosition: {x: 0, y: 0, z: 0}
- pressedPosition: {x: 0, y: 0, z: 0}
- pressDirection: {x: 0, y: -1, z: 0}
- pressMagnitude: 0.1
- autoInit: 1
- size: 3
--- !u!114 &114000011457087486
MonoBehaviour:
m_ObjectHideFlags: 1
@@ -3480,6 +3000,27 @@ MonoBehaviour:
- {fileID: 0}
- {fileID: 0}
m_maskType: 0
+--- !u!114 &114000011638992124
+MonoBehaviour:
+ m_ObjectHideFlags: 1
+ m_PrefabParentObject: {fileID: 0}
+ m_PrefabInternal: {fileID: 100100000}
+ m_GameObject: {fileID: 1000010614386324}
+ m_Enabled: 1
+ m_EditorHideFlags: 0
+ m_Script: {fileID: 11500000, guid: 1a48fa0e48869cd4f8ebae383a32d3fc, type: 3}
+ m_Name:
+ m_EditorClassIdentifier:
+ minScale: 0.4
+ maxScale: 1.2
+ leftMallet: {fileID: 114000012984897716}
+ rightMallet: {fileID: 114000011385624890}
+ leftHandCollider: {fileID: 114000010912951870}
+ rightHandCollider: {fileID: 114000013318402454}
+ settings:
+ position: {x: -0.1, y: -0.47, z: -1}
+ rotation: {x: -0.1979995, y: 0, z: 0, w: 0.9802022}
+ scale: {x: 0.8, y: 0.8, z: 0.8}
--- !u!114 &114000011796479398
MonoBehaviour:
m_ObjectHideFlags: 1
@@ -3614,199 +3155,73 @@ MonoBehaviour:
validationNotice: {fileID: 1000012107024756}
validationMessage: {fileID: 114000013767588498}
infoNotice: {fileID: 1000012078599230}
- infoMessage: {fileID: 114000010592892344}
- successNotice: {fileID: 1000013181315694}
- successMessage: {fileID: 114000011388484120}
- displayTextColor: {r: 0, g: 0, b: 0, a: 1}
- caretColor: {r: 0.5, g: 0.5, b: 0.5, a: 1}
- keyPrefab: {fileID: 1000011322283204}
- keysParent: {fileID: 4000013859835632}
- keyWidth: 0.16
- keyHeight: 0.16
- text:
- canvas: {fileID: 1000010145710606}
- leftMallet: {fileID: 1000012940491476}
- rightMallet: {fileID: 1000011812438282}
- keyboardWrapper: {fileID: 1000011759236714}
- shiftKey: {fileID: 114000012540649824}
- extraKeys:
- - {fileID: 114000012540649824}
- - {fileID: 114000010748070872}
- - {fileID: 114000011968363768}
- - {fileID: 114000011314641286}
- - {fileID: 114000012720594730}
- - {fileID: 114000011825518142}
- - {fileID: 114000014277007508}
- - {fileID: 114000010936285556}
- defaultSize: 2
- sizes:
- - size: 1
- position: {x: -0.1, y: -0.5, z: -1}
- scale: {x: 0.6, y: 0.6, z: 0.6}
- key: {fileID: 114000014094018522}
- - size: 2
- position: {x: -0.1, y: -0.47, z: -1}
- scale: {x: 0.8, y: 0.8, z: 0.8}
- key: {fileID: 114000010924209110}
- - size: 3
- position: {x: -0.1, y: -0.44, z: -1}
- scale: {x: 1, y: 1, z: 1}
- key: {fileID: 114000011431146602}
- leftPressing: 0
- rightPressing: 0
- initialized: 0
- disabled: 1
- OnUpdate:
- m_PersistentCalls:
- m_Calls: []
- m_TypeName: VRKeys.Keyboard+KeyboardUpdateEvent, Assembly-CSharp, Version=0.0.0.0,
- Culture=neutral, PublicKeyToken=null
- OnSubmit:
- m_PersistentCalls:
- m_Calls: []
- m_TypeName: VRKeys.Keyboard+KeyboardSubmitEvent, Assembly-CSharp, Version=0.0.0.0,
- Culture=neutral, PublicKeyToken=null
- OnCancel:
- m_PersistentCalls:
- m_Calls: []
- m_TypeName: UnityEngine.Events.UnityEvent, UnityEngine, Version=0.0.0.0, Culture=neutral,
- PublicKeyToken=null
---- !u!114 &114000011825518142
-MonoBehaviour:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000010921968412}
- m_Enabled: 1
- m_EditorHideFlags: 0
- m_Script: {fileID: 11500000, guid: 20da633ea6ddf744bb835e49bbf6b2d3, type: 3}
- m_Name:
- m_EditorClassIdentifier:
- keyboard: {fileID: 114000011813929276}
- label: {fileID: 114000011796479398}
- inactiveMat: {fileID: 2100000, guid: 021552db260a9654ea7d9d472e44eb58, type: 2}
- activeMat: {fileID: 2100000, guid: 157abfb689445624c97d685110ed6172, type: 2}
- disabledMat: {fileID: 2100000, guid: 05726c44b31fc344db9d054567e02ee4, type: 2}
- defaultPosition: {x: 0, y: 0, z: 0}
- pressedPosition: {x: 0, y: 0, z: 0}
- pressDirection: {x: 0, y: -1, z: 0}
- pressMagnitude: 0.1
- autoInit: 1
- shiftedLabel: {fileID: 114000011796479398}
- character: '@'
- shiftedChar: '@'
---- !u!114 &114000011854418384
-MonoBehaviour:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000010412975446}
- m_Enabled: 1
- m_EditorHideFlags: 0
- m_Script: {fileID: -806885394, guid: b5bd0d848a86e48409fe56688d66ecb5, type: 3}
- m_Name:
- m_EditorClassIdentifier:
- m_Material: {fileID: 0}
- m_Color: {r: 1, g: 1, b: 1, a: 1}
- m_RaycastTarget: 1
- m_OnCullStateChanged:
- m_PersistentCalls:
- m_Calls: []
- m_TypeName: UnityEngine.UI.MaskableGraphic+CullStateChangedEvent, UnityEngine.UI,
- Version=1.0.0.0, Culture=neutral, PublicKeyToken=null
- m_text: S
- m_isRightToLeft: 0
- m_fontAsset: {fileID: 11400000, guid: 715b80e429c437e40867928a4e1fc975, type: 2}
- m_sharedMaterial: {fileID: 2180264, guid: 715b80e429c437e40867928a4e1fc975, type: 2}
- m_fontSharedMaterials: []
- m_fontMaterial: {fileID: 0}
- m_fontMaterials: []
- m_fontColor32:
- serializedVersion: 2
- rgba: 4279505940
- m_fontColor: {r: 0.08088237, g: 0.08088237, b: 0.08088237, a: 1}
- m_enableVertexGradient: 0
- m_fontColorGradient:
- topLeft: {r: 1, g: 1, b: 1, a: 1}
- topRight: {r: 1, g: 1, b: 1, a: 1}
- bottomLeft: {r: 1, g: 1, b: 1, a: 1}
- bottomRight: {r: 1, g: 1, b: 1, a: 1}
- m_fontColorGradientPreset: {fileID: 0}
- m_spriteAsset: {fileID: 0}
- m_tintAllSprites: 0
- m_overrideHtmlColors: 0
- m_faceColor:
- serializedVersion: 2
- rgba: 4294967295
- m_outlineColor:
- serializedVersion: 2
- rgba: 4278190080
- m_fontSize: 7
- m_fontSizeBase: 7
- m_fontWeight: 400
- m_enableAutoSizing: 0
- m_fontSizeMin: 18
- m_fontSizeMax: 72
- m_fontStyle: 0
- m_textAlignment: 514
- m_isAlignmentEnumConverted: 1
- m_characterSpacing: 0
- m_wordSpacing: 0
- m_lineSpacing: 0
- m_lineSpacingMax: 0
- m_paragraphSpacing: 0
- m_charWidthMaxAdj: 0
- m_enableWordWrapping: 1
- m_wordWrappingRatios: 0.4
- m_overflowMode: 0
- m_firstOverflowCharacterIndex: -1
- m_linkedTextComponent: {fileID: 0}
- m_isLinkedTextComponent: 0
- m_enableKerning: 1
- m_enableExtraPadding: 0
- checkPaddingRequired: 0
- m_isRichText: 1
- m_parseCtrlCharacters: 1
- m_isOrthographic: 0
- m_isCullingEnabled: 0
- m_ignoreRectMaskCulling: 0
- m_ignoreCulling: 1
- m_horizontalMapping: 0
- m_verticalMapping: 0
- m_uvLineOffset: 0
- m_geometrySortingOrder: 0
- m_firstVisibleCharacter: 0
- m_useMaxVisibleDescender: 1
- m_pageToDisplay: 1
- m_margin: {x: 0, y: 0, z: 0, w: 0}
- m_textInfo:
- textComponent: {fileID: 114000011854418384}
- characterCount: 1
- spriteCount: 0
- spaceCount: 0
- wordCount: 1
- linkCount: 0
- lineCount: 1
- pageCount: 1
- materialCount: 1
- m_havePropertiesChanged: 1
- m_isUsingLegacyAnimationComponent: 0
- m_isVolumetricText: 0
- m_spriteAnimator: {fileID: 0}
- m_isInputParsingRequired: 1
- m_inputSource: 0
- m_hasFontAssetChanged: 0
- m_renderer: {fileID: 23000010809721506}
- m_subTextObjects:
- - {fileID: 0}
- - {fileID: 0}
- - {fileID: 0}
- - {fileID: 0}
- - {fileID: 0}
- - {fileID: 0}
- - {fileID: 0}
- - {fileID: 0}
- m_maskType: 0
+ infoMessage: {fileID: 114000010592892344}
+ successNotice: {fileID: 1000013181315694}
+ successMessage: {fileID: 114000011388484120}
+ displayTextColor: {r: 0, g: 0, b: 0, a: 1}
+ caretColor: {r: 0.5, g: 0.5, b: 0.5, a: 1}
+ keyPrefab: {fileID: 1000011322283204}
+ keysParent: {fileID: 4000013859835632}
+ keyWidth: 0.16
+ keyHeight: 0.16
+ text:
+ canvas: {fileID: 1000010145710606}
+ leftMallet: {fileID: 1000012940491476}
+ rightMallet: {fileID: 1000011812438282}
+ keyboardWrapper: {fileID: 1000011759236714}
+ shiftKey: {fileID: 114000012540649824}
+ extraKeys:
+ - {fileID: 114000012540649824}
+ - {fileID: 114000010748070872}
+ - {fileID: 114000011968363768}
+ - {fileID: 114000011314641286}
+ - {fileID: 114000012720594730}
+ - {fileID: 114000011825518142}
+ - {fileID: 114000014277007508}
+ - {fileID: 114000010936285556}
+ leftPressing: 0
+ rightPressing: 0
+ initialized: 0
+ disabled: 1
+ OnUpdate:
+ m_PersistentCalls:
+ m_Calls: []
+ m_TypeName: VRKeys.Keyboard+KeyboardUpdateEvent, Assembly-CSharp, Version=0.0.0.0,
+ Culture=neutral, PublicKeyToken=null
+ OnSubmit:
+ m_PersistentCalls:
+ m_Calls: []
+ m_TypeName: VRKeys.Keyboard+KeyboardSubmitEvent, Assembly-CSharp, Version=0.0.0.0,
+ Culture=neutral, PublicKeyToken=null
+ OnCancel:
+ m_PersistentCalls:
+ m_Calls: []
+ m_TypeName: UnityEngine.Events.UnityEvent, UnityEngine, Version=0.0.0.0, Culture=neutral,
+ PublicKeyToken=null
+--- !u!114 &114000011825518142
+MonoBehaviour:
+ m_ObjectHideFlags: 1
+ m_PrefabParentObject: {fileID: 0}
+ m_PrefabInternal: {fileID: 100100000}
+ m_GameObject: {fileID: 1000010921968412}
+ m_Enabled: 1
+ m_EditorHideFlags: 0
+ m_Script: {fileID: 11500000, guid: 20da633ea6ddf744bb835e49bbf6b2d3, type: 3}
+ m_Name:
+ m_EditorClassIdentifier:
+ keyboard: {fileID: 114000011813929276}
+ label: {fileID: 114000011796479398}
+ inactiveMat: {fileID: 2100000, guid: 021552db260a9654ea7d9d472e44eb58, type: 2}
+ activeMat: {fileID: 2100000, guid: 157abfb689445624c97d685110ed6172, type: 2}
+ disabledMat: {fileID: 2100000, guid: 05726c44b31fc344db9d054567e02ee4, type: 2}
+ defaultPosition: {x: 0, y: 0, z: 0}
+ pressedPosition: {x: 0, y: 0, z: 0}
+ pressDirection: {x: 0, y: -1, z: 0}
+ pressMagnitude: 0.1
+ autoInit: 1
+ shiftedLabel: {fileID: 114000011796479398}
+ character: '@'
+ shiftedChar: '@'
--- !u!114 &114000011935164620
MonoBehaviour:
m_ObjectHideFlags: 1
@@ -3984,118 +3399,6 @@ MonoBehaviour:
m_BlockingMask:
serializedVersion: 2
m_Bits: 4294967295
---- !u!114 &114000012236845518
-MonoBehaviour:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000012063527344}
- m_Enabled: 1
- m_EditorHideFlags: 0
- m_Script: {fileID: -806885394, guid: b5bd0d848a86e48409fe56688d66ecb5, type: 3}
- m_Name:
- m_EditorClassIdentifier:
- m_Material: {fileID: 0}
- m_Color: {r: 1, g: 1, b: 1, a: 1}
- m_RaycastTarget: 1
- m_OnCullStateChanged:
- m_PersistentCalls:
- m_Calls: []
- m_TypeName: UnityEngine.UI.MaskableGraphic+CullStateChangedEvent, UnityEngine.UI,
- Version=1.0.0.0, Culture=neutral, PublicKeyToken=null
- m_text: M
- m_isRightToLeft: 0
- m_fontAsset: {fileID: 11400000, guid: 715b80e429c437e40867928a4e1fc975, type: 2}
- m_sharedMaterial: {fileID: 2180264, guid: 715b80e429c437e40867928a4e1fc975, type: 2}
- m_fontSharedMaterials: []
- m_fontMaterial: {fileID: 0}
- m_fontMaterials: []
- m_fontColor32:
- serializedVersion: 2
- rgba: 4279505940
- m_fontColor: {r: 0.08088237, g: 0.08088237, b: 0.08088237, a: 1}
- m_enableVertexGradient: 0
- m_fontColorGradient:
- topLeft: {r: 1, g: 1, b: 1, a: 1}
- topRight: {r: 1, g: 1, b: 1, a: 1}
- bottomLeft: {r: 1, g: 1, b: 1, a: 1}
- bottomRight: {r: 1, g: 1, b: 1, a: 1}
- m_fontColorGradientPreset: {fileID: 0}
- m_spriteAsset: {fileID: 0}
- m_tintAllSprites: 0
- m_overrideHtmlColors: 0
- m_faceColor:
- serializedVersion: 2
- rgba: 4294967295
- m_outlineColor:
- serializedVersion: 2
- rgba: 4278190080
- m_fontSize: 7
- m_fontSizeBase: 7
- m_fontWeight: 400
- m_enableAutoSizing: 0
- m_fontSizeMin: 18
- m_fontSizeMax: 72
- m_fontStyle: 0
- m_textAlignment: 514
- m_isAlignmentEnumConverted: 1
- m_characterSpacing: 0
- m_wordSpacing: 0
- m_lineSpacing: 0
- m_lineSpacingMax: 0
- m_paragraphSpacing: 0
- m_charWidthMaxAdj: 0
- m_enableWordWrapping: 1
- m_wordWrappingRatios: 0.4
- m_overflowMode: 0
- m_firstOverflowCharacterIndex: -1
- m_linkedTextComponent: {fileID: 0}
- m_isLinkedTextComponent: 0
- m_enableKerning: 1
- m_enableExtraPadding: 0
- checkPaddingRequired: 0
- m_isRichText: 1
- m_parseCtrlCharacters: 1
- m_isOrthographic: 0
- m_isCullingEnabled: 0
- m_ignoreRectMaskCulling: 0
- m_ignoreCulling: 1
- m_horizontalMapping: 0
- m_verticalMapping: 0
- m_uvLineOffset: 0
- m_geometrySortingOrder: 0
- m_firstVisibleCharacter: 0
- m_useMaxVisibleDescender: 1
- m_pageToDisplay: 1
- m_margin: {x: 0, y: 0, z: 0, w: 0}
- m_textInfo:
- textComponent: {fileID: 114000012236845518}
- characterCount: 1
- spriteCount: 0
- spaceCount: 0
- wordCount: 1
- linkCount: 0
- lineCount: 1
- pageCount: 1
- materialCount: 1
- m_havePropertiesChanged: 1
- m_isUsingLegacyAnimationComponent: 0
- m_isVolumetricText: 0
- m_spriteAnimator: {fileID: 0}
- m_isInputParsingRequired: 1
- m_inputSource: 0
- m_hasFontAssetChanged: 0
- m_renderer: {fileID: 23000012023175106}
- m_subTextObjects:
- - {fileID: 0}
- - {fileID: 0}
- - {fileID: 0}
- - {fileID: 0}
- - {fileID: 0}
- - {fileID: 0}
- - {fileID: 0}
- - {fileID: 0}
- m_maskType: 0
--- !u!114 &114000012351115726
MonoBehaviour:
m_ObjectHideFlags: 1
@@ -4308,6 +3611,7 @@ MonoBehaviour:
m_EditorClassIdentifier:
clipToPlay: {fileID: 8300000, guid: 3432185da42c61f4aa9e8c9da931dd8e, type: 3}
hand: 0
+ handCollider: {fileID: 114000010912951870}
--- !u!114 &114000013061632910
MonoBehaviour:
m_ObjectHideFlags: 1
@@ -4444,6 +3748,19 @@ MonoBehaviour:
- {fileID: 0}
- {fileID: 0}
m_maskType: 0
+--- !u!114 &114000013318402454
+MonoBehaviour:
+ m_ObjectHideFlags: 1
+ m_PrefabParentObject: {fileID: 0}
+ m_PrefabInternal: {fileID: 100100000}
+ m_GameObject: {fileID: 1000013340159164}
+ m_Enabled: 1
+ m_EditorHideFlags: 0
+ m_Script: {fileID: 11500000, guid: 10db60974c6c8b145bf8a61883659e98, type: 3}
+ m_Name:
+ m_EditorClassIdentifier:
+ mallet: {fileID: 114000011385624890}
+ inKeyboard: 0
--- !u!114 &114000013633238574
MonoBehaviour:
m_ObjectHideFlags: 1
@@ -4780,28 +4097,6 @@ MonoBehaviour:
- {fileID: 0}
- {fileID: 0}
m_maskType: 0
---- !u!114 &114000014094018522
-MonoBehaviour:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000010089480526}
- m_Enabled: 1
- m_EditorHideFlags: 0
- m_Script: {fileID: 11500000, guid: c16caca778364914aa98ebe1f690817a, type: 3}
- m_Name:
- m_EditorClassIdentifier:
- keyboard: {fileID: 114000011813929276}
- label: {fileID: 114000011854418384}
- inactiveMat: {fileID: 2100000, guid: 021552db260a9654ea7d9d472e44eb58, type: 2}
- activeMat: {fileID: 2100000, guid: 157abfb689445624c97d685110ed6172, type: 2}
- disabledMat: {fileID: 2100000, guid: 05726c44b31fc344db9d054567e02ee4, type: 2}
- defaultPosition: {x: 0, y: 0, z: 0}
- pressedPosition: {x: 0, y: 0, z: 0}
- pressDirection: {x: 0, y: -1, z: 0}
- pressMagnitude: 0.1
- autoInit: 1
- size: 1
--- !u!114 &114000014124921810
MonoBehaviour:
m_ObjectHideFlags: 1
@@ -5092,12 +4387,6 @@ CanvasRenderer:
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
m_GameObject: {fileID: 1000011740335272}
---- !u!222 &222000010435183204
-CanvasRenderer:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000012063527344}
--- !u!222 &222000010502615314
CanvasRenderer:
m_ObjectHideFlags: 1
@@ -5128,24 +4417,12 @@ CanvasRenderer:
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
m_GameObject: {fileID: 1000010315705958}
---- !u!222 &222000012199324066
-CanvasRenderer:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000010412975446}
--- !u!222 &222000012297233544
CanvasRenderer:
m_ObjectHideFlags: 1
m_PrefabParentObject: {fileID: 0}
m_PrefabInternal: {fileID: 100100000}
m_GameObject: {fileID: 1000013739334028}
---- !u!222 &222000012420626692
-CanvasRenderer:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000012703070624}
--- !u!222 &222000012510626848
CanvasRenderer:
m_ObjectHideFlags: 1
@@ -5262,24 +4539,6 @@ RectTransform:
m_AnchoredPosition: {x: -0.125, y: 0.55}
m_SizeDelta: {x: 0.7, y: 0.8}
m_Pivot: {x: 0.5, y: 0.5}
---- !u!224 &224000010236752756
-RectTransform:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000012703070624}
- m_LocalRotation: {x: 0.7071068, y: 0, z: 0, w: 0.7071068}
- m_LocalPosition: {x: 0, y: 0, z: -0.05}
- m_LocalScale: {x: 1, y: 1, z: 1}
- m_LocalEulerAnglesHint: {x: 90, y: 0, z: 0}
- m_Children: []
- m_Father: {fileID: 4000011234500342}
- m_RootOrder: 0
- m_AnchorMin: {x: 0.5, y: 0.5}
- m_AnchorMax: {x: 0.5, y: 0.5}
- m_AnchoredPosition: {x: 0, y: 0.55}
- m_SizeDelta: {x: 0.7, y: 0.8}
- m_Pivot: {x: 0.5, y: 0.5}
--- !u!224 &224000010241926686
RectTransform:
m_ObjectHideFlags: 1
@@ -5316,24 +4575,6 @@ RectTransform:
m_AnchoredPosition: {x: 0, y: 0.55}
m_SizeDelta: {x: 2, y: 1}
m_Pivot: {x: 0.5, y: 0.5}
---- !u!224 &224000010573683446
-RectTransform:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000010412975446}
- m_LocalRotation: {x: 0.7071068, y: 0, z: 0, w: 0.7071068}
- m_LocalPosition: {x: 0, y: 0, z: -0.05}
- m_LocalScale: {x: 1, y: 1, z: 1}
- m_LocalEulerAnglesHint: {x: 90, y: 0, z: 0}
- m_Children: []
- m_Father: {fileID: 4000011636982694}
- m_RootOrder: 0
- m_AnchorMin: {x: 0.5, y: 0.5}
- m_AnchorMax: {x: 0.5, y: 0.5}
- m_AnchoredPosition: {x: 0, y: 0.55}
- m_SizeDelta: {x: 0.7, y: 0.8}
- m_Pivot: {x: 0.5, y: 0.5}
--- !u!224 &224000010670433422
RectTransform:
m_ObjectHideFlags: 1
@@ -5612,24 +4853,6 @@ RectTransform:
m_AnchoredPosition: {x: 0, y: 0.55}
m_SizeDelta: {x: 0.7, y: 0.8}
m_Pivot: {x: 0.5, y: 0.5}
---- !u!224 &224000013948607280
-RectTransform:
- m_ObjectHideFlags: 1
- m_PrefabParentObject: {fileID: 0}
- m_PrefabInternal: {fileID: 100100000}
- m_GameObject: {fileID: 1000012063527344}
- m_LocalRotation: {x: 0.7071068, y: 0, z: 0, w: 0.7071068}
- m_LocalPosition: {x: 0, y: 0, z: -0.05}
- m_LocalScale: {x: 1, y: 1, z: 1}
- m_LocalEulerAnglesHint: {x: 90, y: 0, z: 0}
- m_Children: []
- m_Father: {fileID: 4000012689466318}
- m_RootOrder: 0
- m_AnchorMin: {x: 0.5, y: 0.5}
- m_AnchorMax: {x: 0.5, y: 0.5}
- m_AnchoredPosition: {x: 0, y: 0.55}
- m_SizeDelta: {x: 0.7, y: 0.8}
- m_Pivot: {x: 0.5, y: 0.5}
--- !u!224 &224000014007350124
RectTransform:
m_ObjectHideFlags: 1
diff --git a/Assets/VRKeys/Scenes/VRKeys Example.unity b/Assets/VRKeys/Scenes/VRKeys Example.unity
index 45f3ebc..3c78f41 100644
--- a/Assets/VRKeys/Scenes/VRKeys Example.unity
+++ b/Assets/VRKeys/Scenes/VRKeys Example.unity
@@ -37,7 +37,7 @@ RenderSettings:
m_ReflectionIntensity: 1
m_CustomReflection: {fileID: 0}
m_Sun: {fileID: 0}
- m_IndirectSpecularColor: {r: 0.24648565, g: 0.2823304, b: 0.34567446, a: 1}
+ m_IndirectSpecularColor: {r: 0.18053626, g: 0.2260185, b: 0.30718803, a: 1}
--- !u!157 &3
LightmapSettings:
m_ObjectHideFlags: 0
@@ -90,63 +90,6 @@ NavMeshSettings:
cellSize: 0.16666667
manualCellSize: 0
m_NavMeshData: {fileID: 0}
---- !u!1001 &352954129
-Prefab:
- m_ObjectHideFlags: 0
- serializedVersion: 2
- m_Modification:
- m_TransformParent: {fileID: 0}
- m_Modifications:
- - target: {fileID: 4000013025176432, guid: f28287b1c722ebd4aa4f4d8547ed7fa8, type: 2}
- propertyPath: m_LocalPosition.x
- value: 0
- objectReference: {fileID: 0}
- - target: {fileID: 4000013025176432, guid: f28287b1c722ebd4aa4f4d8547ed7fa8, type: 2}
- propertyPath: m_LocalPosition.y
- value: 1.35
- objectReference: {fileID: 0}
- - target: {fileID: 4000013025176432, guid: f28287b1c722ebd4aa4f4d8547ed7fa8, type: 2}
- propertyPath: m_LocalPosition.z
- value: 2
- objectReference: {fileID: 0}
- - target: {fileID: 4000013025176432, guid: f28287b1c722ebd4aa4f4d8547ed7fa8, type: 2}
- propertyPath: m_LocalRotation.x
- value: 0
- objectReference: {fileID: 0}
- - target: {fileID: 4000013025176432, guid: f28287b1c722ebd4aa4f4d8547ed7fa8, type: 2}
- propertyPath: m_LocalRotation.y
- value: 0
- objectReference: {fileID: 0}
- - target: {fileID: 4000013025176432, guid: f28287b1c722ebd4aa4f4d8547ed7fa8, type: 2}
- propertyPath: m_LocalRotation.z
- value: 0
- objectReference: {fileID: 0}
- - target: {fileID: 4000013025176432, guid: f28287b1c722ebd4aa4f4d8547ed7fa8, type: 2}
- propertyPath: m_LocalRotation.w
- value: 1
- objectReference: {fileID: 0}
- - target: {fileID: 4000013025176432, guid: f28287b1c722ebd4aa4f4d8547ed7fa8, type: 2}
- propertyPath: m_RootOrder
- value: 2
- objectReference: {fileID: 0}
- - target: {fileID: 114000011813929276, guid: f28287b1c722ebd4aa4f4d8547ed7fa8,
- type: 2}
- propertyPath: playerSpace
- value:
- objectReference: {fileID: 585723786}
- - target: {fileID: 114000011813929276, guid: f28287b1c722ebd4aa4f4d8547ed7fa8,
- type: 2}
- propertyPath: leftHand
- value:
- objectReference: {fileID: 585723785}
- - target: {fileID: 114000011813929276, guid: f28287b1c722ebd4aa4f4d8547ed7fa8,
- type: 2}
- propertyPath: rightHand
- value:
- objectReference: {fileID: 585723784}
- m_RemovedComponents: []
- m_ParentPrefab: {fileID: 100100000, guid: f28287b1c722ebd4aa4f4d8547ed7fa8, type: 2}
- m_IsPrefabParent: 0
--- !u!1001 &585723783
Prefab:
m_ObjectHideFlags: 0
@@ -188,7 +131,7 @@ Prefab:
objectReference: {fileID: 0}
- target: {fileID: 11457864, guid: b0047dd65ff208349bf3a5aaaeae24d0, type: 2}
propertyPath: SteamVREnabled
- value: 0
+ value: 1
objectReference: {fileID: 0}
- target: {fileID: 11457864, guid: b0047dd65ff208349bf3a5aaaeae24d0, type: 2}
propertyPath: OculusSDKEnabled
@@ -210,6 +153,10 @@ Prefab:
propertyPath: m_LocalEulerAnglesHint.y
value: 0
objectReference: {fileID: 0}
+ - target: {fileID: 11457864, guid: b0047dd65ff208349bf3a5aaaeae24d0, type: 2}
+ propertyPath: PhysicalHands
+ value: 0
+ objectReference: {fileID: 0}
m_RemovedComponents: []
m_ParentPrefab: {fileID: 100100000, guid: b0047dd65ff208349bf3a5aaaeae24d0, type: 2}
m_IsPrefabParent: 0
@@ -292,8 +239,65 @@ Transform:
MonoBehaviour:
m_PrefabParentObject: {fileID: 114000011813929276, guid: f28287b1c722ebd4aa4f4d8547ed7fa8,
type: 2}
- m_PrefabInternal: {fileID: 352954129}
+ m_PrefabInternal: {fileID: 1835141285}
m_Script: {fileID: 11500000, guid: fb08f495a9bc93a46b97e507bf9be1b3, type: 3}
+--- !u!1001 &1835141285
+Prefab:
+ m_ObjectHideFlags: 0
+ serializedVersion: 2
+ m_Modification:
+ m_TransformParent: {fileID: 0}
+ m_Modifications:
+ - target: {fileID: 4000013025176432, guid: f28287b1c722ebd4aa4f4d8547ed7fa8, type: 2}
+ propertyPath: m_LocalPosition.x
+ value: 0
+ objectReference: {fileID: 0}
+ - target: {fileID: 4000013025176432, guid: f28287b1c722ebd4aa4f4d8547ed7fa8, type: 2}
+ propertyPath: m_LocalPosition.y
+ value: 1.35
+ objectReference: {fileID: 0}
+ - target: {fileID: 4000013025176432, guid: f28287b1c722ebd4aa4f4d8547ed7fa8, type: 2}
+ propertyPath: m_LocalPosition.z
+ value: 2
+ objectReference: {fileID: 0}
+ - target: {fileID: 4000013025176432, guid: f28287b1c722ebd4aa4f4d8547ed7fa8, type: 2}
+ propertyPath: m_LocalRotation.x
+ value: 0
+ objectReference: {fileID: 0}
+ - target: {fileID: 4000013025176432, guid: f28287b1c722ebd4aa4f4d8547ed7fa8, type: 2}
+ propertyPath: m_LocalRotation.y
+ value: 0
+ objectReference: {fileID: 0}
+ - target: {fileID: 4000013025176432, guid: f28287b1c722ebd4aa4f4d8547ed7fa8, type: 2}
+ propertyPath: m_LocalRotation.z
+ value: 0
+ objectReference: {fileID: 0}
+ - target: {fileID: 4000013025176432, guid: f28287b1c722ebd4aa4f4d8547ed7fa8, type: 2}
+ propertyPath: m_LocalRotation.w
+ value: 1
+ objectReference: {fileID: 0}
+ - target: {fileID: 4000013025176432, guid: f28287b1c722ebd4aa4f4d8547ed7fa8, type: 2}
+ propertyPath: m_RootOrder
+ value: 2
+ objectReference: {fileID: 0}
+ - target: {fileID: 114000011813929276, guid: f28287b1c722ebd4aa4f4d8547ed7fa8,
+ type: 2}
+ propertyPath: playerSpace
+ value:
+ objectReference: {fileID: 585723786}
+ - target: {fileID: 114000011813929276, guid: f28287b1c722ebd4aa4f4d8547ed7fa8,
+ type: 2}
+ propertyPath: leftHand
+ value:
+ objectReference: {fileID: 585723785}
+ - target: {fileID: 114000011813929276, guid: f28287b1c722ebd4aa4f4d8547ed7fa8,
+ type: 2}
+ propertyPath: rightHand
+ value:
+ objectReference: {fileID: 585723784}
+ m_RemovedComponents: []
+ m_ParentPrefab: {fileID: 100100000, guid: f28287b1c722ebd4aa4f4d8547ed7fa8, type: 2}
+ m_IsPrefabParent: 0
--- !u!1 &2042955739
GameObject:
m_ObjectHideFlags: 0
diff --git a/Assets/VRKeys/Scripts/SizeKey.cs.meta b/Assets/VRKeys/Scripts/Controller.cs.meta
similarity index 76%
rename from Assets/VRKeys/Scripts/SizeKey.cs.meta
rename to Assets/VRKeys/Scripts/Controller.cs.meta
index 7bc450e..e7ead5e 100644
--- a/Assets/VRKeys/Scripts/SizeKey.cs.meta
+++ b/Assets/VRKeys/Scripts/Controller.cs.meta
@@ -1,6 +1,6 @@
fileFormatVersion: 2
-guid: c16caca778364914aa98ebe1f690817a
-timeCreated: 1499113164
+guid: bf97c4e6f48a71449ad18f71801c6693
+timeCreated: 1504464685
licenseType: Free
MonoImporter:
serializedVersion: 2
diff --git a/Assets/VRKeys/Scripts/HandCollider.cs b/Assets/VRKeys/Scripts/HandCollider.cs
new file mode 100644
index 0000000..0b3ebe0
--- /dev/null
+++ b/Assets/VRKeys/Scripts/HandCollider.cs
@@ -0,0 +1,32 @@
+/**
+ * Copyright (c) 2017 The Campfire Union Inc - All Rights Reserved.
+ *
+ * Licensed under the MIT license. See LICENSE file in the project root for
+ * full license information.
+ *
+ * Email: info@campfireunion.com
+ * Website: https://www.campfireunion.com
+ */
+
+using UnityEngine;
+using System.Collections;
+
+namespace VRKeys {
+ public class HandCollider : MonoBehaviour {
+ public Mallet mallet;
+
+ public bool inKeyboard = false;
+
+ void OnTriggerEnter (Collider other) {
+ if (other.gameObject.name == "KeyboardCollider") {
+ inKeyboard = true;
+ }
+ }
+
+ void OnTriggerExit (Collider other) {
+ if (other.gameObject.name == "KeyboardCollider") {
+ inKeyboard = false;
+ }
+ }
+ }
+}
\ No newline at end of file
diff --git a/Assets/VRKeys/Scripts/Haptics.cs.meta b/Assets/VRKeys/Scripts/HandCollider.cs.meta
similarity index 69%
rename from Assets/VRKeys/Scripts/Haptics.cs.meta
rename to Assets/VRKeys/Scripts/HandCollider.cs.meta
index 8ed6455..d9292e2 100644
--- a/Assets/VRKeys/Scripts/Haptics.cs.meta
+++ b/Assets/VRKeys/Scripts/HandCollider.cs.meta
@@ -1,7 +1,7 @@
fileFormatVersion: 2
-guid: 573987f5bb2fa454297a6ab091d53b52
-timeCreated: 1503688549
-licenseType: Pro
+guid: 10db60974c6c8b145bf8a61883659e98
+timeCreated: 1504466365
+licenseType: Free
MonoImporter:
serializedVersion: 2
defaultReferences: []
diff --git a/Assets/VRKeys/Scripts/Keyboard.cs b/Assets/VRKeys/Scripts/Keyboard.cs
index 328f308..c1e72b4 100644
--- a/Assets/VRKeys/Scripts/Keyboard.cs
+++ b/Assets/VRKeys/Scripts/Keyboard.cs
@@ -86,26 +86,6 @@ public class Keyboard : MonoBehaviour {
public Key[] extraKeys;
- public enum KeyboardSize {
- Small = 1,
- Medium = 2,
- Large = 3
- }
-
- [Serializable]
- public class SizeInfo {
- public KeyboardSize size;
- public Vector3 position;
- public Vector3 scale;
- public SizeKey key;
- }
-
- [Space (15)]
- public KeyboardSize defaultSize = KeyboardSize.Medium;
-
- [SerializeField]
- public SizeInfo[] sizes;
-
[Space (15)]
public bool leftPressing = false;
@@ -142,8 +122,6 @@ public class KeyboardSubmitEvent : UnityEvent { }
private bool shifted = false;
- private KeyboardSize size;
-
private Layout layout;
///
@@ -159,12 +137,6 @@ private IEnumerator Start () {
UpdateDisplayText ();
PlaceholderVisibility ();
- if (PlayerPrefs.HasKey ("vrkeys:size")) {
- defaultSize = (KeyboardSize) PlayerPrefs.GetInt ("vrkeys:size");
- }
-
- Resize (defaultSize);
-
initialized = true;
}
@@ -375,35 +347,6 @@ public void Cancel () {
Disable ();
}
- ///
- /// Resize the keyboard.
- ///
- /// New size.
- public void Resize (KeyboardSize newSize) {
- DisableInput ();
-
- PlayerPrefs.SetInt ("vrkeys:size", (int) newSize);
- size = newSize;
-
- foreach (SizeInfo info in sizes) {
- if (info.size == size) {
- keyboardWrapper.transform.localPosition = info.position;
- keyboardWrapper.transform.localScale = info.scale;
- }
- info.key.SetActiveSize (size);
- }
-
- if (initialized && !disabled) {
- StartCoroutine (DelayEnableAfterResize ());
- }
- }
-
- private IEnumerator DelayEnableAfterResize () {
- yield return new WaitForSeconds (0.3f);
-
- EnableInput ();
- }
-
///
/// Set the language of the keyboard.
///
@@ -424,11 +367,6 @@ private IEnumerator DoSetLanguage (KeyboardLayout lang) {
foreach (Key key in extraKeys) {
key.UpdateLayout (layout);
}
-
- // Update size keys
- foreach (SizeInfo info in sizes) {
- info.key.UpdateLayout (layout);
- }
}
///
diff --git a/Assets/VRKeys/Scripts/Layout.cs b/Assets/VRKeys/Scripts/Layout.cs
index 77d2d99..f2e15b5 100644
--- a/Assets/VRKeys/Scripts/Layout.cs
+++ b/Assets/VRKeys/Scripts/Layout.cs
@@ -33,12 +33,6 @@ public class Layout {
public string clearButtonLabel = "CLEAR";
- public string smallButtonLabel = "S";
-
- public string mediumButtonLabel = "M";
-
- public string largeButtonLabel = "L";
-
public string[] row1Keys = { "`", "1", "2", "3", "4", "5", "6", "7", "8", "9", "0", "-", "=" };
public string[] row1Shift = { "~", "!", "@", "#", "$", "%", "^", "&", "*", "(", ")", "_", "+" };
diff --git a/Assets/VRKeys/Scripts/Layouts/French.cs b/Assets/VRKeys/Scripts/Layouts/French.cs
index d36c4b7..e83e692 100644
--- a/Assets/VRKeys/Scripts/Layouts/French.cs
+++ b/Assets/VRKeys/Scripts/Layouts/French.cs
@@ -31,12 +31,6 @@ public French () {
clearButtonLabel = "EFFACER";
- smallButtonLabel = "P";
-
- mediumButtonLabel = "M";
-
- largeButtonLabel = "G";
-
row1Keys = new string[] { "â", "&", "é", "\"", "'", "(", "-", "è", "_", "ç", "à", ")", "=" };
row1Shift = new string[] { "ê", "1", "2", "3", "4", "5", "6", "7", "8", "9", "0", "-", "ë" };
diff --git a/Assets/VRKeys/Scripts/Mallet.cs b/Assets/VRKeys/Scripts/Mallet.cs
index f1b2ed5..1aae658 100644
--- a/Assets/VRKeys/Scripts/Mallet.cs
+++ b/Assets/VRKeys/Scripts/Mallet.cs
@@ -29,6 +29,8 @@ public enum MalletHand {
public MalletHand hand;
+ public HandCollider handCollider;
+
public bool isMovingDownward {
get { return _isMovingDownward; }
private set { _isMovingDownward = value; }
@@ -38,7 +40,7 @@ public bool isMovingDownward {
private AudioSource audioSource;
- private Haptics haptics;
+ private Controller controller;
private Vector3 prevPos = Vector3.zero;
@@ -47,11 +49,11 @@ private void Awake () {
switch (VRSettings.loadedDeviceName) {
case "Oculus":
- haptics = gameObject.AddComponent ();
+ controller = gameObject.AddComponent ();
break;
case "OpenVR":
- haptics = gameObject.AddComponent ();
+ controller = gameObject.AddComponent ();
break;
}
}
@@ -72,8 +74,16 @@ public void HandleTriggerEnter (Key key) {
audioSource.PlayOneShot (clipToPlay);
if (transform.parent.transform.parent != null) {
- haptics.TriggerPulse ();
+ controller.TriggerPulse ();
}
}
+
+ ///
+ /// Get the attached Controller class for input abstractions.
+ ///
+ /// Controller.
+ public Controller Controller () {
+ return controller;
+ }
}
}
\ No newline at end of file
diff --git a/Assets/VRKeys/Scripts/Placement.cs b/Assets/VRKeys/Scripts/Placement.cs
new file mode 100644
index 0000000..e470d90
--- /dev/null
+++ b/Assets/VRKeys/Scripts/Placement.cs
@@ -0,0 +1,176 @@
+/**
+ * Copyright (c) 2017 The Campfire Union Inc - All Rights Reserved.
+ *
+ * Licensed under the MIT license. See LICENSE file in the project root for
+ * full license information.
+ *
+ * Email: info@campfireunion.com
+ * Website: https://www.campfireunion.com
+ */
+
+using UnityEngine;
+using System;
+using System.Collections;
+
+namespace VRKeys {
+ ///
+ /// Manages placement of the keyboard relative to the user, including
+ /// grabbing it to move and resize the keyboard.
+ ///
+ public class Placement : MonoBehaviour {
+
+ [Serializable]
+ public class PlacementSettings {
+ public Vector3 position;
+ public Quaternion rotation;
+ public Vector3 scale;
+ }
+
+ public float minScale = 0.4f;
+
+ public float maxScale = 1.2f;
+
+ public Mallet leftMallet;
+
+ public Mallet rightMallet;
+
+ public HandCollider leftHandCollider;
+
+ public HandCollider rightHandCollider;
+
+ public PlacementSettings settings;
+
+ private Keyboard keyboard;
+
+ private HandCollider positioningHand;
+
+ private Vector3 previousPosition;
+
+ private float previousRotationX;
+
+ private Vector3 initialScale;
+
+ private float applyScale = 1f;
+
+ private float initialHandDistance = -1f;
+
+ private float initialApplyScale = 1f;
+
+ private string prefsKey = "vrkeys:placement";
+
+ void Awake () {
+ keyboard = GetComponent ();
+
+ if (PlayerPrefs.HasKey (prefsKey)) {
+ JsonUtility.FromJsonOverwrite (PlayerPrefs.GetString (prefsKey), settings);
+ }
+
+ keyboard.keyboardWrapper.transform.localPosition = settings.position;
+ keyboard.keyboardWrapper.transform.localRotation = settings.rotation;
+ keyboard.keyboardWrapper.transform.localScale = settings.scale;
+
+ initialScale = keyboard.keyboardWrapper.transform.localScale;
+ }
+
+ void Update () {
+ if (!leftHandCollider.inKeyboard && !rightHandCollider.inKeyboard) {
+ ResetState ();
+ return;
+ };
+
+ bool leftGrip = false;
+ bool rightGrip = false;
+ bool changed = false;
+
+ if (leftMallet.Controller () != null) {
+ leftGrip = leftMallet.Controller ().OnGrip ();
+ }
+
+ if (rightMallet.Controller () != null) {
+ rightGrip = rightMallet.Controller ().OnGrip ();
+ }
+
+ // Positioning
+ if (leftGrip) {
+ PositionWith (leftHandCollider);
+ changed = true;
+ } else if (rightGrip) {
+ PositionWith (rightHandCollider);
+ changed = true;
+ }
+
+ // Resizing
+ if (leftGrip && rightGrip) {
+ Resize ();
+ changed = true;
+ }
+
+ if (changed) {
+ SaveChanges ();
+ } else {
+ ResetState ();
+ }
+ }
+
+ void PositionWith (HandCollider hand) {
+ if (positioningHand != hand) {
+ positioningHand = hand;
+ previousPosition = hand.transform.position;
+ previousRotationX = hand.transform.rotation.eulerAngles.x;
+ }
+
+ var pos = keyboard.keyboardWrapper.transform.localPosition;
+
+ keyboard.keyboardWrapper.transform.localPosition = new Vector3 (
+ pos.x + (hand.transform.position.x - previousPosition.x),
+ pos.y + (hand.transform.position.y - previousPosition.y),
+ pos.z + (hand.transform.position.z - previousPosition.z)
+ );
+
+ var rot = keyboard.keyboardWrapper.transform.eulerAngles;
+
+ keyboard.keyboardWrapper.transform.localRotation = Quaternion.Euler (
+ rot.x + (hand.transform.eulerAngles.x - previousRotationX),
+ rot.y,
+ rot.z
+ );
+
+ previousPosition = hand.transform.position;
+ previousRotationX = hand.transform.eulerAngles.x;
+ }
+
+ void Resize () {
+ if (initialHandDistance == -1f) {
+ initialHandDistance = Vector3.Distance (leftHandCollider.transform.position, rightHandCollider.transform.position);
+ initialApplyScale = applyScale;
+ return;
+ }
+
+ var curDistance = Vector3.Distance (leftHandCollider.transform.position, rightHandCollider.transform.position);
+
+ applyScale = initialApplyScale + (initialApplyScale * (curDistance - initialHandDistance));
+
+ if (applyScale < minScale) {
+ applyScale = minScale;
+ } else if (applyScale > maxScale) {
+ applyScale = maxScale;
+ }
+
+ keyboard.keyboardWrapper.transform.localScale = initialScale * applyScale;
+ }
+
+ void ResetState () {
+ initialHandDistance = -1f;
+ initialApplyScale = 1f;
+ positioningHand = null;
+ }
+
+ void SaveChanges () {
+ settings.position = keyboard.keyboardWrapper.transform.localPosition;
+ settings.rotation = keyboard.keyboardWrapper.transform.localRotation;
+ settings.scale = keyboard.keyboardWrapper.transform.localScale;
+
+ PlayerPrefs.SetString (prefsKey, JsonUtility.ToJson (settings));
+ }
+ }
+}
\ No newline at end of file
diff --git a/Assets/VRKeys/Scripts/Placement.cs.meta b/Assets/VRKeys/Scripts/Placement.cs.meta
new file mode 100644
index 0000000..46f23d7
--- /dev/null
+++ b/Assets/VRKeys/Scripts/Placement.cs.meta
@@ -0,0 +1,12 @@
+fileFormatVersion: 2
+guid: 1a48fa0e48869cd4f8ebae383a32d3fc
+timeCreated: 1504467195
+licenseType: Free
+MonoImporter:
+ serializedVersion: 2
+ defaultReferences: []
+ executionOrder: 0
+ icon: {instanceID: 0}
+ userData:
+ assetBundleName:
+ assetBundleVariant:
diff --git a/Assets/VRKeys/Scripts/Platforms/OculusHaptics.cs b/Assets/VRKeys/Scripts/Platforms/OculusController.cs
similarity index 59%
rename from Assets/VRKeys/Scripts/Platforms/OculusHaptics.cs
rename to Assets/VRKeys/Scripts/Platforms/OculusController.cs
index dcdc747..d0ffd44 100644
--- a/Assets/VRKeys/Scripts/Platforms/OculusHaptics.cs
+++ b/Assets/VRKeys/Scripts/Platforms/OculusController.cs
@@ -13,22 +13,36 @@
namespace VRKeys {
- public class OculusHaptics : Haptics {
+ public class OculusController : Controller {
+
+ private OVRInput.Controller _controller;
+ private OVRInput.Controller controller {
+ get {
+ if (_controller == OVRInput.Controller.None) {
+ _controller = (mallet.hand == Mallet.MalletHand.Left)
+ ? OVRInput.Controller.LTouch
+ : OVRInput.Controller.RTouch;
+ }
+ return _controller;
+ }
+ }
public override void TriggerPulse () {
StartCoroutine (DoTriggerPulse ());
}
private IEnumerator DoTriggerPulse () {
- var controller = (mallet.hand == Mallet.MalletHand.Left) ? OVRInput.Controller.LTouch : OVRInput.Controller.RTouch;
OVRInput.SetControllerVibration (0.3f, 0.3f, controller);
yield return null;
OVRInput.SetControllerVibration (0f, 0f, controller);
}
private void OnDisable () {
- var controller = (mallet.hand == Mallet.MalletHand.Left) ? OVRInput.Controller.LTouch : OVRInput.Controller.RTouch;
OVRInput.SetControllerVibration (0f, 0f, controller);
}
+
+ public override bool OnGrip () {
+ return OVRInput.Get (OVRInput.Button.PrimaryHandTrigger, controller);
+ }
}
}
\ No newline at end of file
diff --git a/Assets/VRKeys/Scripts/Platforms/OculusHaptics.cs.meta b/Assets/VRKeys/Scripts/Platforms/OculusController.cs.meta
similarity index 100%
rename from Assets/VRKeys/Scripts/Platforms/OculusHaptics.cs.meta
rename to Assets/VRKeys/Scripts/Platforms/OculusController.cs.meta
diff --git a/Assets/VRKeys/Scripts/Platforms/OpenVRController.cs b/Assets/VRKeys/Scripts/Platforms/OpenVRController.cs
new file mode 100644
index 0000000..5caa0ce
--- /dev/null
+++ b/Assets/VRKeys/Scripts/Platforms/OpenVRController.cs
@@ -0,0 +1,47 @@
+/**
+ * Copyright (c) 2017 The Campfire Union Inc - All Rights Reserved.
+ *
+ * Licensed under the MIT license. See LICENSE file in the project root for
+ * full license information.
+ *
+ * Email: info@campfireunion.com
+ * Website: https://www.campfireunion.com
+ */
+
+using UnityEngine;
+using System.Collections;
+using Valve.VR;
+
+namespace VRKeys {
+
+ public class OpenVRController : Controller {
+
+ private SteamVR_Controller.Device _controller;
+ private SteamVR_Controller.Device controller {
+ get {
+ if (_controller == null) {
+ var trackedObject = GetComponentInParent ();
+ if (trackedObject == null) return null;
+
+ var deviceIndex = (int) trackedObject.index;
+ if (deviceIndex == -1) return null;
+
+ _controller = SteamVR_Controller.Input (deviceIndex);
+ }
+ return _controller;
+ }
+ }
+
+ public override void TriggerPulse () {
+ if (controller == null) return;
+
+ controller.TriggerHapticPulse (800);
+ }
+
+ public override bool OnGrip () {
+ if (controller == null) return false;
+
+ return controller.GetPress (SteamVR_Controller.ButtonMask.Grip);
+ }
+ }
+}
\ No newline at end of file
diff --git a/Assets/VRKeys/Scripts/Platforms/OpenVRHaptics.cs.meta b/Assets/VRKeys/Scripts/Platforms/OpenVRController.cs.meta
similarity index 100%
rename from Assets/VRKeys/Scripts/Platforms/OpenVRHaptics.cs.meta
rename to Assets/VRKeys/Scripts/Platforms/OpenVRController.cs.meta
diff --git a/Assets/VRKeys/Scripts/Platforms/OpenVRHaptics.cs b/Assets/VRKeys/Scripts/Platforms/OpenVRHaptics.cs
deleted file mode 100644
index b7ef57c..0000000
--- a/Assets/VRKeys/Scripts/Platforms/OpenVRHaptics.cs
+++ /dev/null
@@ -1,37 +0,0 @@
-/**
- * Copyright (c) 2017 The Campfire Union Inc - All Rights Reserved.
- *
- * Licensed under the MIT license. See LICENSE file in the project root for
- * full license information.
- *
- * Email: info@campfireunion.com
- * Website: https://www.campfireunion.com
- */
-
-using UnityEngine;
-using System.Collections;
-using Valve.VR;
-
-namespace VRKeys {
-
- public class OpenVRHaptics : Haptics {
-
- private int deviceIndex = -1;
-
- private SteamVR_Controller.Device controller;
-
- public override void TriggerPulse () {
- if (deviceIndex == -1) {
- var trackedObject = GetComponentInParent ();
- if (trackedObject == null) return;
-
- deviceIndex = (int) trackedObject.index;
- if (deviceIndex == -1) return;
-
- controller = SteamVR_Controller.Input (deviceIndex);
- }
-
- controller.TriggerHapticPulse (800);
- }
- }
-}
\ No newline at end of file
diff --git a/Assets/VRKeys/Scripts/SizeKey.cs b/Assets/VRKeys/Scripts/SizeKey.cs
deleted file mode 100644
index 8ceca09..0000000
--- a/Assets/VRKeys/Scripts/SizeKey.cs
+++ /dev/null
@@ -1,62 +0,0 @@
-/**
- * Copyright (c) 2017 The Campfire Union Inc - All Rights Reserved.
- *
- * Licensed under the MIT license. See LICENSE file in the project root for
- * full license information.
- *
- * Email: info@campfireunion.com
- * Website: https://www.campfireunion.com
- */
-
-using UnityEngine;
-using System.Collections;
-
-namespace VRKeys {
-
- ///
- /// Key for resizing the keyboard.
- ///
- public class SizeKey : Key {
- public Keyboard.KeyboardSize size;
-
- private bool isActive = false;
-
- protected override void OnEnableExtras () {
- meshRenderer.material = isActive ? activeMat : inactiveMat;
- }
-
- public override void HandleTriggerEnter (Collider other) {
- keyboard.Resize (size);
- }
-
- public void SetActiveSize (Keyboard.KeyboardSize activeSize) {
- if (meshRenderer == null) {
- meshRenderer = GetComponent ();
- }
-
- if (size == activeSize) {
- isActive = true;
- meshRenderer.material = activeMat;
- } else {
- isActive = false;
- meshRenderer.material = inactiveMat;
- }
- }
-
- public override void UpdateLayout (Layout translation) {
- switch (size) {
- case Keyboard.KeyboardSize.Small:
- label.text = translation.smallButtonLabel;
- break;
-
- case Keyboard.KeyboardSize.Medium:
- label.text = translation.mediumButtonLabel;
- break;
-
- case Keyboard.KeyboardSize.Large:
- label.text = translation.largeButtonLabel;
- break;
- }
- }
- }
-}
\ No newline at end of file
diff --git a/Assets/VRKeys/Scripts/Haptics.cs b/Assets/VRKeys/Scripts/Controller.cs
similarity index 74%
rename from Assets/VRKeys/Scripts/Haptics.cs
rename to Assets/VRKeys/Scripts/Controller.cs
index 6eeb947..b16c083 100644
--- a/Assets/VRKeys/Scripts/Haptics.cs
+++ b/Assets/VRKeys/Scripts/Controller.cs
@@ -12,11 +12,10 @@
using System.Collections;
namespace VRKeys {
-
///
/// Base class for platform-specific haptics.
///
- public class Haptics : MonoBehaviour {
+ public class Controller : MonoBehaviour {
protected Mallet mallet;
private void Start () {
@@ -26,5 +25,10 @@ private void Start () {
public virtual void TriggerPulse () {
// Override me!
}
+
+ public virtual bool OnGrip () {
+ // Override me!
+ return false;
+ }
}
}
\ No newline at end of file
@@ -12,11 +12,10 @@
///
- /// Base class for platform-specific haptics.
+ /// Base class for platform-specific inputs and controller access.
///